/* Autogenerated */
/* curve description: p192 */
/* requested operations: (all) */
/* n = 7 (from "7") */
/* s-c = 2^192 - [(2^64, 1), (1, 1)] (from "2^192 - 2^64 - 1") */
/* machine_wordsize = 32 (from "32") */

/* Computed values: */
/* carry_chain = [1, 6, 2, 0, 3, 1, 4, 5, 6, 2, 0] */

#include <stdint.h>
typedef unsigned char fiat_p192_uint1;
typedef signed char fiat_p192_int1;
typedef signed __int128 fiat_p192_int128;
typedef unsigned __int128 fiat_p192_uint128;

#if (-1 & 3) != 3
#error "This code only works on a two's complement system"
#endif


/*
 * The function fiat_p192_addcarryx_u28 is an addition with carry.
 * Postconditions:
 *   out1 = (arg1 + arg2 + arg3) mod 2^28
 *   out2 = ⌊(arg1 + arg2 + arg3) / 2^28⌋
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [0x0 ~> 0xfffffff]
 *   arg3: [0x0 ~> 0xfffffff]
 * Output Bounds:
 *   out1: [0x0 ~> 0xfffffff]
 *   out2: [0x0 ~> 0x1]
 */
static void fiat_p192_addcarryx_u28(uint32_t* out1, fiat_p192_uint1* out2, fiat_p192_uint1 arg1, uint32_t arg2, uint32_t arg3) {
  uint32_t x1 = ((arg1 + arg2) + arg3);
  uint32_t x2 = (x1 & UINT32_C(0xfffffff));
  fiat_p192_uint1 x3 = (fiat_p192_uint1)(x1 >> 28);
  *out1 = x2;
  *out2 = x3;
}

/*
 * The function fiat_p192_subborrowx_u28 is a subtraction with borrow.
 * Postconditions:
 *   out1 = (-arg1 + arg2 + -arg3) mod 2^28
 *   out2 = -⌊(-arg1 + arg2 + -arg3) / 2^28⌋
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [0x0 ~> 0xfffffff]
 *   arg3: [0x0 ~> 0xfffffff]
 * Output Bounds:
 *   out1: [0x0 ~> 0xfffffff]
 *   out2: [0x0 ~> 0x1]
 */
static void fiat_p192_subborrowx_u28(uint32_t* out1, fiat_p192_uint1* out2, fiat_p192_uint1 arg1, uint32_t arg2, uint32_t arg3) {
  int32_t x1 = ((int32_t)(arg2 - arg1) - (int32_t)arg3);
  fiat_p192_int1 x2 = (fiat_p192_int1)(x1 >> 28);
  uint32_t x3 = (x1 & UINT32_C(0xfffffff));
  *out1 = x3;
  *out2 = (fiat_p192_uint1)(0x0 - x2);
}

/*
 * The function fiat_p192_addcarryx_u27 is an addition with carry.
 * Postconditions:
 *   out1 = (arg1 + arg2 + arg3) mod 2^27
 *   out2 = ⌊(arg1 + arg2 + arg3) / 2^27⌋
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [0x0 ~> 0x7ffffff]
 *   arg3: [0x0 ~> 0x7ffffff]
 * Output Bounds:
 *   out1: [0x0 ~> 0x7ffffff]
 *   out2: [0x0 ~> 0x1]
 */
static void fiat_p192_addcarryx_u27(uint32_t* out1, fiat_p192_uint1* out2, fiat_p192_uint1 arg1, uint32_t arg2, uint32_t arg3) {
  uint32_t x1 = ((arg1 + arg2) + arg3);
  uint32_t x2 = (x1 & UINT32_C(0x7ffffff));
  fiat_p192_uint1 x3 = (fiat_p192_uint1)(x1 >> 27);
  *out1 = x2;
  *out2 = x3;
}

/*
 * The function fiat_p192_subborrowx_u27 is a subtraction with borrow.
 * Postconditions:
 *   out1 = (-arg1 + arg2 + -arg3) mod 2^27
 *   out2 = -⌊(-arg1 + arg2 + -arg3) / 2^27⌋
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [0x0 ~> 0x7ffffff]
 *   arg3: [0x0 ~> 0x7ffffff]
 * Output Bounds:
 *   out1: [0x0 ~> 0x7ffffff]
 *   out2: [0x0 ~> 0x1]
 */
static void fiat_p192_subborrowx_u27(uint32_t* out1, fiat_p192_uint1* out2, fiat_p192_uint1 arg1, uint32_t arg2, uint32_t arg3) {
  int32_t x1 = ((int32_t)(arg2 - arg1) - (int32_t)arg3);
  fiat_p192_int1 x2 = (fiat_p192_int1)(x1 >> 27);
  uint32_t x3 = (x1 & UINT32_C(0x7ffffff));
  *out1 = x3;
  *out2 = (fiat_p192_uint1)(0x0 - x2);
}

/*
 * The function fiat_p192_cmovznz_u32 is a single-word conditional move.
 * Postconditions:
 *   out1 = (if arg1 = 0 then arg2 else arg3)
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [0x0 ~> 0xffffffff]
 *   arg3: [0x0 ~> 0xffffffff]
 * Output Bounds:
 *   out1: [0x0 ~> 0xffffffff]
 */
static void fiat_p192_cmovznz_u32(uint32_t* out1, fiat_p192_uint1 arg1, uint32_t arg2, uint32_t arg3) {
  fiat_p192_uint1 x1 = (!(!arg1));
  uint32_t x2 = ((fiat_p192_int1)(0x0 - x1) & UINT32_C(0xffffffff));
  uint32_t x3 = ((x2 & arg3) | ((~x2) & arg2));
  *out1 = x3;
}

/*
 * The function fiat_p192_carry_mul multiplies two field elements and reduces the result.
 * Postconditions:
 *   eval out1 mod m = (eval arg1 * eval arg2) mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x1a666664]]
 *   arg2: [[0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x1a666664]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x8cccccc]]
 */
static void fiat_p192_carry_mul(uint32_t out1[7], const uint32_t arg1[7], const uint32_t arg2[7]) {
  fiat_p192_uint128 x1 = ((fiat_p192_uint128)((uint64_t)(arg1[6]) * (arg2[6])) << 10);
  fiat_p192_uint128 x2 = ((fiat_p192_uint128)((uint64_t)(arg1[6]) * (arg2[6])) << 19);
  uint64_t x3 = ((uint64_t)(arg1[6]) * (arg2[6]));
  uint64_t x4 = ((uint64_t)(arg1[6]) * ((arg2[5]) * (uint32_t)0x2));
  uint64_t x5 = ((uint64_t)(arg1[6]) * (arg2[4]));
  uint64_t x6 = ((uint64_t)(arg1[6]) * ((arg2[3]) * (uint32_t)0x2));
  uint64_t x7 = ((uint64_t)(arg1[6]) * (arg2[2]));
  uint64_t x8 = ((uint64_t)(arg1[6]) * ((arg2[1]) * (uint32_t)0x2));
  uint64_t x9 = ((uint64_t)(arg1[5]) * ((arg2[6]) * (uint32_t)0x2));
  uint64_t x10 = ((uint64_t)(arg1[5]) * ((arg2[5]) * (uint32_t)0x2));
  uint64_t x11 = ((uint64_t)(arg1[5]) * ((arg2[4]) * (uint32_t)0x2));
  uint64_t x12 = ((uint64_t)(arg1[5]) * ((arg2[3]) * (uint32_t)0x2));
  uint64_t x13 = ((uint64_t)(arg1[5]) * ((arg2[2]) * (uint32_t)0x2));
  uint64_t x14 = ((uint64_t)(arg1[4]) * (arg2[6]));
  uint64_t x15 = ((uint64_t)(arg1[4]) * ((arg2[5]) * (uint32_t)0x2));
  uint64_t x16 = ((uint64_t)(arg1[4]) * (arg2[4]));
  uint64_t x17 = ((uint64_t)(arg1[4]) * ((arg2[3]) * (uint32_t)0x2));
  uint64_t x18 = ((uint64_t)(arg1[3]) * ((arg2[6]) * (uint32_t)0x2));
  uint64_t x19 = ((uint64_t)(arg1[3]) * ((arg2[5]) * (uint32_t)0x2));
  uint64_t x20 = ((uint64_t)(arg1[3]) * ((arg2[4]) * (uint32_t)0x2));
  uint64_t x21 = ((uint64_t)(arg1[2]) * (arg2[6]));
  uint64_t x22 = ((uint64_t)(arg1[2]) * ((arg2[5]) * (uint32_t)0x2));
  uint64_t x23 = ((uint64_t)(arg1[1]) * ((arg2[6]) * (uint32_t)0x2));
  fiat_p192_uint128 x24 = ((fiat_p192_uint128)((uint64_t)(arg1[6]) * (arg2[5])) << 10);
  fiat_p192_uint128 x25 = ((fiat_p192_uint128)((uint64_t)(arg1[6]) * (arg2[4])) << 9);
  fiat_p192_uint128 x26 = ((fiat_p192_uint128)((uint64_t)(arg1[6]) * (arg2[3])) << 10);
  fiat_p192_uint128 x27 = ((fiat_p192_uint128)((uint64_t)(arg1[6]) * (arg2[2])) << 9);
  fiat_p192_uint128 x28 = ((fiat_p192_uint128)((uint64_t)(arg1[6]) * (arg2[1])) << 10);
  fiat_p192_uint128 x29 = ((fiat_p192_uint128)((uint64_t)(arg1[5]) * (arg2[6])) << 10);
  fiat_p192_uint128 x30 = ((fiat_p192_uint128)((uint64_t)(arg1[5]) * (arg2[5])) << 10);
  fiat_p192_uint128 x31 = ((fiat_p192_uint128)((uint64_t)(arg1[5]) * (arg2[4])) << 10);
  fiat_p192_uint128 x32 = ((fiat_p192_uint128)((uint64_t)(arg1[5]) * (arg2[3])) << 10);
  fiat_p192_uint128 x33 = ((fiat_p192_uint128)((uint64_t)(arg1[5]) * (arg2[2])) << 10);
  fiat_p192_uint128 x34 = ((fiat_p192_uint128)((uint64_t)(arg1[4]) * (arg2[6])) << 9);
  fiat_p192_uint128 x35 = ((fiat_p192_uint128)((uint64_t)(arg1[4]) * (arg2[5])) << 10);
  fiat_p192_uint128 x36 = ((fiat_p192_uint128)((uint64_t)(arg1[4]) * (arg2[4])) << 9);
  fiat_p192_uint128 x37 = ((fiat_p192_uint128)((uint64_t)(arg1[4]) * (arg2[3])) << 10);
  fiat_p192_uint128 x38 = ((fiat_p192_uint128)((uint64_t)(arg1[3]) * (arg2[6])) << 10);
  fiat_p192_uint128 x39 = ((fiat_p192_uint128)((uint64_t)(arg1[3]) * (arg2[5])) << 10);
  fiat_p192_uint128 x40 = ((fiat_p192_uint128)((uint64_t)(arg1[3]) * (arg2[4])) << 10);
  fiat_p192_uint128 x41 = ((fiat_p192_uint128)((uint64_t)(arg1[2]) * (arg2[6])) << 9);
  fiat_p192_uint128 x42 = ((fiat_p192_uint128)((uint64_t)(arg1[2]) * (arg2[5])) << 10);
  fiat_p192_uint128 x43 = ((fiat_p192_uint128)((uint64_t)(arg1[1]) * (arg2[6])) << 10);
  uint64_t x44 = ((uint64_t)(arg1[6]) * (arg2[0]));
  uint64_t x45 = ((uint64_t)(arg1[5]) * ((arg2[1]) * (uint32_t)0x2));
  uint64_t x46 = ((uint64_t)(arg1[5]) * (arg2[0]));
  uint64_t x47 = ((uint64_t)(arg1[4]) * (arg2[2]));
  uint64_t x48 = ((uint64_t)(arg1[4]) * (arg2[1]));
  uint64_t x49 = ((uint64_t)(arg1[4]) * (arg2[0]));
  uint64_t x50 = ((uint64_t)(arg1[3]) * ((arg2[3]) * (uint32_t)0x2));
  uint64_t x51 = ((uint64_t)(arg1[3]) * (arg2[2]));
  uint64_t x52 = ((uint64_t)(arg1[3]) * ((arg2[1]) * (uint32_t)0x2));
  uint64_t x53 = ((uint64_t)(arg1[3]) * (arg2[0]));
  uint64_t x54 = ((uint64_t)(arg1[2]) * (arg2[4]));
  uint64_t x55 = ((uint64_t)(arg1[2]) * (arg2[3]));
  uint64_t x56 = ((uint64_t)(arg1[2]) * (arg2[2]));
  uint64_t x57 = ((uint64_t)(arg1[2]) * (arg2[1]));
  uint64_t x58 = ((uint64_t)(arg1[2]) * (arg2[0]));
  uint64_t x59 = ((uint64_t)(arg1[1]) * ((arg2[5]) * (uint32_t)0x2));
  uint64_t x60 = ((uint64_t)(arg1[1]) * (arg2[4]));
  uint64_t x61 = ((uint64_t)(arg1[1]) * ((arg2[3]) * (uint32_t)0x2));
  uint64_t x62 = ((uint64_t)(arg1[1]) * (arg2[2]));
  uint64_t x63 = ((uint64_t)(arg1[1]) * ((arg2[1]) * (uint32_t)0x2));
  uint64_t x64 = ((uint64_t)(arg1[1]) * (arg2[0]));
  uint64_t x65 = ((uint64_t)(arg1[0]) * (arg2[6]));
  uint64_t x66 = ((uint64_t)(arg1[0]) * (arg2[5]));
  uint64_t x67 = ((uint64_t)(arg1[0]) * (arg2[4]));
  uint64_t x68 = ((uint64_t)(arg1[0]) * (arg2[3]));
  uint64_t x69 = ((uint64_t)(arg1[0]) * (arg2[2]));
  uint64_t x70 = ((uint64_t)(arg1[0]) * (arg2[1]));
  uint64_t x71 = ((uint64_t)(arg1[0]) * (arg2[0]));
  uint64_t x72 = (x70 + (x64 + (x21 + (x19 + (x16 + (x12 + x7))))));
  uint64_t x73 = (x72 >> 27);
  uint32_t x74 = (uint32_t)(x72 & UINT32_C(0x7ffffff));
  fiat_p192_uint128 x75 = (x65 + (x59 + (x54 + (x50 + (x47 + (x45 + (x44 + (x29 + x24))))))));
  fiat_p192_uint128 x76 = (x66 + (x60 + (x55 + (x51 + (x48 + (x46 + (x34 + (x30 + (x25 + x3)))))))));
  fiat_p192_uint128 x77 = (x67 + (x61 + (x56 + (x52 + (x49 + (x38 + (x35 + (x31 + (x26 + (x9 + x4))))))))));
  fiat_p192_uint128 x78 = (x68 + (x62 + (x57 + (x53 + (x41 + (x39 + (x36 + (x32 + (x27 + (x14 + (x10 + x5)))))))))));
  fiat_p192_uint128 x79 = (x69 + (x63 + (x58 + (x43 + (x42 + (x40 + (x37 + (x33 + (x28 + (x18 + (x15 + (x11 + (x6 + x2)))))))))))));
  fiat_p192_uint128 x80 = (x71 + (x23 + (x22 + (x20 + (x17 + (x13 + (x8 + x1)))))));
  fiat_p192_uint128 x81 = (x73 + x79);
  uint64_t x82 = (uint64_t)(x75 >> 27);
  uint32_t x83 = (uint32_t)(x75 & UINT32_C(0x7ffffff));
  uint64_t x84 = (x82 << 9);
  fiat_p192_uint128 x85 = (x81 + x84);
  uint64_t x86 = (uint64_t)(x85 >> 28);
  uint32_t x87 = (uint32_t)(x85 & UINT32_C(0xfffffff));
  fiat_p192_uint128 x88 = (x80 + x82);
  fiat_p192_uint128 x89 = (x86 + x78);
  uint64_t x90 = (uint64_t)(x88 >> 28);
  uint32_t x91 = (uint32_t)(x88 & UINT32_C(0xfffffff));
  uint64_t x92 = (x90 + x74);
  uint64_t x93 = (uint64_t)(x89 >> 27);
  uint32_t x94 = (uint32_t)(x89 & UINT32_C(0x7ffffff));
  fiat_p192_uint128 x95 = (x93 + x77);
  uint32_t x96 = (uint32_t)(x92 >> 27);
  uint32_t x97 = (uint32_t)(x92 & UINT32_C(0x7ffffff));
  uint32_t x98 = (x96 + x87);
  uint64_t x99 = (uint64_t)(x95 >> 28);
  uint32_t x100 = (uint32_t)(x95 & UINT32_C(0xfffffff));
  fiat_p192_uint128 x101 = (x99 + x76);
  uint64_t x102 = (uint64_t)(x101 >> 27);
  uint32_t x103 = (uint32_t)(x101 & UINT32_C(0x7ffffff));
  uint64_t x104 = (x102 + x83);
  uint32_t x105 = (uint32_t)(x104 >> 27);
  uint32_t x106 = (uint32_t)(x104 & UINT32_C(0x7ffffff));
  uint32_t x107 = (x105 << 9);
  uint32_t x108 = (x98 + x107);
  uint32_t x109 = (x108 >> 28);
  uint32_t x110 = (x108 & UINT32_C(0xfffffff));
  uint32_t x111 = (x91 + x105);
  uint32_t x112 = (x109 + x94);
  uint32_t x113 = (x111 >> 28);
  uint32_t x114 = (x111 & UINT32_C(0xfffffff));
  uint32_t x115 = (x113 + x97);
  out1[0] = x114;
  out1[1] = x115;
  out1[2] = x110;
  out1[3] = x112;
  out1[4] = x100;
  out1[5] = x103;
  out1[6] = x106;
}

/*
 * The function fiat_p192_carry_square squares a field element and reduces the result.
 * Postconditions:
 *   eval out1 mod m = (eval arg1 * eval arg1) mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x1a666664]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x8cccccc]]
 */
static void fiat_p192_carry_square(uint32_t out1[7], const uint32_t arg1[7]) {
  uint32_t x1 = (arg1[6]);
  uint32_t x2 = (arg1[6]);
  uint32_t x3 = (x1 * (uint32_t)0x2);
  uint32_t x4 = (x2 * (uint32_t)0x2);
  uint32_t x5 = ((arg1[6]) * (uint32_t)0x2);
  uint32_t x6 = (arg1[5]);
  uint32_t x7 = (arg1[5]);
  uint32_t x8 = (x6 * (uint32_t)0x2);
  uint32_t x9 = (x7 * (uint32_t)0x2);
  uint32_t x10 = ((arg1[5]) * (uint32_t)0x2);
  uint32_t x11 = (arg1[4]);
  uint32_t x12 = (arg1[4]);
  uint32_t x13 = (x11 * (uint32_t)0x2);
  uint32_t x14 = (x12 * (uint32_t)0x2);
  uint32_t x15 = ((arg1[4]) * (uint32_t)0x2);
  uint32_t x16 = ((arg1[3]) * (uint32_t)0x2);
  uint32_t x17 = ((arg1[2]) * (uint32_t)0x2);
  uint32_t x18 = ((arg1[1]) * (uint32_t)0x2);
  fiat_p192_uint128 x19 = ((fiat_p192_uint128)((uint64_t)(arg1[6]) * x1) << 10);
  fiat_p192_uint128 x20 = ((fiat_p192_uint128)((uint64_t)(arg1[6]) * x1) << 19);
  uint64_t x21 = ((uint64_t)(arg1[6]) * x2);
  uint64_t x22 = ((uint64_t)(arg1[5]) * (x4 * (uint32_t)0x2));
  fiat_p192_uint128 x23 = ((fiat_p192_uint128)((uint64_t)(arg1[5]) * x3) << 10);
  uint64_t x24 = ((uint64_t)(arg1[5]) * (x7 * (uint32_t)0x2));
  fiat_p192_uint128 x25 = ((fiat_p192_uint128)((uint64_t)(arg1[5]) * x6) << 10);
  uint64_t x26 = ((uint64_t)(arg1[4]) * x4);
  fiat_p192_uint128 x27 = ((fiat_p192_uint128)((uint64_t)(arg1[4]) * x3) << 9);
  uint64_t x28 = ((uint64_t)(arg1[4]) * (x9 * (uint32_t)0x2));
  fiat_p192_uint128 x29 = ((fiat_p192_uint128)((uint64_t)(arg1[4]) * x8) << 10);
  uint64_t x30 = ((uint64_t)(arg1[4]) * x12);
  fiat_p192_uint128 x31 = ((fiat_p192_uint128)((uint64_t)(arg1[4]) * x11) << 9);
  uint64_t x32 = ((uint64_t)(arg1[3]) * (x4 * (uint32_t)0x2));
  fiat_p192_uint128 x33 = ((fiat_p192_uint128)((uint64_t)(arg1[3]) * x3) << 10);
  uint64_t x34 = ((uint64_t)(arg1[3]) * (x9 * (uint32_t)0x2));
  fiat_p192_uint128 x35 = ((fiat_p192_uint128)((uint64_t)(arg1[3]) * x8) << 10);
  uint64_t x36 = ((uint64_t)(arg1[3]) * (x14 * (uint32_t)0x2));
  fiat_p192_uint128 x37 = ((fiat_p192_uint128)((uint64_t)(arg1[3]) * x13) << 10);
  uint64_t x38 = ((uint64_t)(arg1[3]) * ((arg1[3]) * (uint32_t)0x2));
  uint64_t x39 = ((uint64_t)(arg1[2]) * x4);
  fiat_p192_uint128 x40 = ((fiat_p192_uint128)((uint64_t)(arg1[2]) * x3) << 9);
  uint64_t x41 = ((uint64_t)(arg1[2]) * (x9 * (uint32_t)0x2));
  fiat_p192_uint128 x42 = ((fiat_p192_uint128)((uint64_t)(arg1[2]) * x8) << 10);
  uint64_t x43 = ((uint64_t)(arg1[2]) * x15);
  uint64_t x44 = ((uint64_t)(arg1[2]) * x16);
  uint64_t x45 = ((uint64_t)(arg1[2]) * (arg1[2]));
  uint64_t x46 = ((uint64_t)(arg1[1]) * (x4 * (uint32_t)0x2));
  fiat_p192_uint128 x47 = ((fiat_p192_uint128)((uint64_t)(arg1[1]) * x3) << 10);
  uint64_t x48 = ((uint64_t)(arg1[1]) * (x10 * (uint32_t)0x2));
  uint64_t x49 = ((uint64_t)(arg1[1]) * x15);
  uint64_t x50 = ((uint64_t)(arg1[1]) * (x16 * (uint32_t)0x2));
  uint64_t x51 = ((uint64_t)(arg1[1]) * x17);
  uint64_t x52 = ((uint64_t)(arg1[1]) * ((arg1[1]) * (uint32_t)0x2));
  uint64_t x53 = ((uint64_t)(arg1[0]) * x5);
  uint64_t x54 = ((uint64_t)(arg1[0]) * x10);
  uint64_t x55 = ((uint64_t)(arg1[0]) * x15);
  uint64_t x56 = ((uint64_t)(arg1[0]) * x16);
  uint64_t x57 = ((uint64_t)(arg1[0]) * x17);
  uint64_t x58 = ((uint64_t)(arg1[0]) * x18);
  uint64_t x59 = ((uint64_t)(arg1[0]) * (arg1[0]));
  uint64_t x60 = (x58 + (x39 + (x34 + x30)));
  uint64_t x61 = (x60 >> 27);
  uint32_t x62 = (uint32_t)(x60 & UINT32_C(0x7ffffff));
  fiat_p192_uint128 x63 = (x53 + (x48 + (x43 + (x38 + x23))));
  fiat_p192_uint128 x64 = (x54 + (x49 + (x44 + (x27 + (x25 + x21)))));
  fiat_p192_uint128 x65 = (x55 + (x50 + (x45 + (x33 + (x29 + x22)))));
  fiat_p192_uint128 x66 = (x56 + (x51 + (x40 + (x35 + (x31 + (x26 + x24))))));
  fiat_p192_uint128 x67 = (x57 + (x52 + (x47 + (x42 + (x37 + (x32 + (x28 + x20)))))));
  fiat_p192_uint128 x68 = (x59 + (x46 + (x41 + (x36 + x19))));
  fiat_p192_uint128 x69 = (x61 + x67);
  uint64_t x70 = (uint64_t)(x63 >> 27);
  uint32_t x71 = (uint32_t)(x63 & UINT32_C(0x7ffffff));
  uint64_t x72 = (x70 << 9);
  fiat_p192_uint128 x73 = (x69 + x72);
  uint64_t x74 = (uint64_t)(x73 >> 28);
  uint32_t x75 = (uint32_t)(x73 & UINT32_C(0xfffffff));
  fiat_p192_uint128 x76 = (x68 + x70);
  fiat_p192_uint128 x77 = (x74 + x66);
  uint64_t x78 = (uint64_t)(x76 >> 28);
  uint32_t x79 = (uint32_t)(x76 & UINT32_C(0xfffffff));
  uint64_t x80 = (x78 + x62);
  uint64_t x81 = (uint64_t)(x77 >> 27);
  uint32_t x82 = (uint32_t)(x77 & UINT32_C(0x7ffffff));
  fiat_p192_uint128 x83 = (x81 + x65);
  uint32_t x84 = (uint32_t)(x80 >> 27);
  uint32_t x85 = (uint32_t)(x80 & UINT32_C(0x7ffffff));
  uint32_t x86 = (x84 + x75);
  uint64_t x87 = (uint64_t)(x83 >> 28);
  uint32_t x88 = (uint32_t)(x83 & UINT32_C(0xfffffff));
  fiat_p192_uint128 x89 = (x87 + x64);
  uint64_t x90 = (uint64_t)(x89 >> 27);
  uint32_t x91 = (uint32_t)(x89 & UINT32_C(0x7ffffff));
  uint64_t x92 = (x90 + x71);
  uint32_t x93 = (uint32_t)(x92 >> 27);
  uint32_t x94 = (uint32_t)(x92 & UINT32_C(0x7ffffff));
  uint32_t x95 = (x93 << 9);
  uint32_t x96 = (x86 + x95);
  uint32_t x97 = (x96 >> 28);
  uint32_t x98 = (x96 & UINT32_C(0xfffffff));
  uint32_t x99 = (x79 + x93);
  uint32_t x100 = (x97 + x82);
  uint32_t x101 = (x99 >> 28);
  uint32_t x102 = (x99 & UINT32_C(0xfffffff));
  uint32_t x103 = (x101 + x85);
  out1[0] = x102;
  out1[1] = x103;
  out1[2] = x98;
  out1[3] = x100;
  out1[4] = x88;
  out1[5] = x91;
  out1[6] = x94;
}

/*
 * The function fiat_p192_carry reduces a field element.
 * Postconditions:
 *   eval out1 mod m = eval arg1 mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x1a666664]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x8cccccc]]
 */
static void fiat_p192_carry(uint32_t out1[7], const uint32_t arg1[7]) {
  uint32_t x1 = (arg1[1]);
  uint32_t x2 = (arg1[6]);
  uint32_t x3 = (x2 >> 27);
  uint32_t x4 = (((x1 >> 27) + (arg1[2])) + (x3 << 9));
  uint32_t x5 = ((arg1[0]) + x3);
  uint32_t x6 = ((x4 >> 28) + (arg1[3]));
  uint32_t x7 = ((x5 >> 28) + (x1 & UINT32_C(0x7ffffff)));
  uint32_t x8 = ((x6 >> 27) + (arg1[4]));
  uint32_t x9 = ((x8 >> 28) + (arg1[5]));
  uint32_t x10 = ((x9 >> 27) + (x2 & UINT32_C(0x7ffffff)));
  uint32_t x11 = (x10 >> 27);
  uint32_t x12 = (((x7 >> 27) + (x4 & UINT32_C(0xfffffff))) + (x11 << 9));
  uint32_t x13 = ((x5 & UINT32_C(0xfffffff)) + x11);
  uint32_t x14 = (x13 & UINT32_C(0xfffffff));
  uint32_t x15 = ((x13 >> 28) + (x7 & UINT32_C(0x7ffffff)));
  uint32_t x16 = (x12 & UINT32_C(0xfffffff));
  uint32_t x17 = ((x12 >> 28) + (x6 & UINT32_C(0x7ffffff)));
  uint32_t x18 = (x8 & UINT32_C(0xfffffff));
  uint32_t x19 = (x9 & UINT32_C(0x7ffffff));
  uint32_t x20 = (x10 & UINT32_C(0x7ffffff));
  out1[0] = x14;
  out1[1] = x15;
  out1[2] = x16;
  out1[3] = x17;
  out1[4] = x18;
  out1[5] = x19;
  out1[6] = x20;
}

/*
 * The function fiat_p192_add adds two field elements.
 * Postconditions:
 *   eval out1 mod m = (eval arg1 + eval arg2) mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x8cccccc]]
 *   arg2: [[0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x8cccccc]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x1a666664]]
 */
static void fiat_p192_add(uint32_t out1[7], const uint32_t arg1[7], const uint32_t arg2[7]) {
  uint32_t x1 = ((arg1[0]) + (arg2[0]));
  uint32_t x2 = ((arg1[1]) + (arg2[1]));
  uint32_t x3 = ((arg1[2]) + (arg2[2]));
  uint32_t x4 = ((arg1[3]) + (arg2[3]));
  uint32_t x5 = ((arg1[4]) + (arg2[4]));
  uint32_t x6 = ((arg1[5]) + (arg2[5]));
  uint32_t x7 = ((arg1[6]) + (arg2[6]));
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
}

/*
 * The function fiat_p192_sub subtracts two field elements.
 * Postconditions:
 *   eval out1 mod m = (eval arg1 - eval arg2) mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x8cccccc]]
 *   arg2: [[0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x8cccccc]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x1a666664]]
 */
static void fiat_p192_sub(uint32_t out1[7], const uint32_t arg1[7], const uint32_t arg2[7]) {
  uint32_t x1 = ((UINT32_C(0x1ffffffe) + (arg1[0])) - (arg2[0]));
  uint32_t x2 = ((UINT32_C(0xffffffe) + (arg1[1])) - (arg2[1]));
  uint32_t x3 = ((UINT32_C(0x1ffffbfe) + (arg1[2])) - (arg2[2]));
  uint32_t x4 = ((UINT32_C(0xffffffe) + (arg1[3])) - (arg2[3]));
  uint32_t x5 = ((UINT32_C(0x1ffffffe) + (arg1[4])) - (arg2[4]));
  uint32_t x6 = ((UINT32_C(0xffffffe) + (arg1[5])) - (arg2[5]));
  uint32_t x7 = ((UINT32_C(0xffffffe) + (arg1[6])) - (arg2[6]));
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
}

/*
 * The function fiat_p192_opp negates a field element.
 * Postconditions:
 *   eval out1 mod m = -eval arg1 mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x8cccccc]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x34cccccb], [0x0 ~> 0x1a666664], [0x0 ~> 0x1a666664]]
 */
static void fiat_p192_opp(uint32_t out1[7], const uint32_t arg1[7]) {
  uint32_t x1 = (UINT32_C(0x1ffffffe) - (arg1[0]));
  uint32_t x2 = (UINT32_C(0xffffffe) - (arg1[1]));
  uint32_t x3 = (UINT32_C(0x1ffffbfe) - (arg1[2]));
  uint32_t x4 = (UINT32_C(0xffffffe) - (arg1[3]));
  uint32_t x5 = (UINT32_C(0x1ffffffe) - (arg1[4]));
  uint32_t x6 = (UINT32_C(0xffffffe) - (arg1[5]));
  uint32_t x7 = (UINT32_C(0xffffffe) - (arg1[6]));
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
}

/*
 * The function fiat_p192_selectznz is a multi-limb conditional select.
 * Postconditions:
 *   eval out1 = (if arg1 = 0 then eval arg2 else eval arg3)
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [[0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff]]
 *   arg3: [[0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff]]
 */
static void fiat_p192_selectznz(uint32_t out1[7], fiat_p192_uint1 arg1, const uint32_t arg2[7], const uint32_t arg3[7]) {
  uint32_t x1;
  fiat_p192_cmovznz_u32(&x1, arg1, (arg2[0]), (arg3[0]));
  uint32_t x2;
  fiat_p192_cmovznz_u32(&x2, arg1, (arg2[1]), (arg3[1]));
  uint32_t x3;
  fiat_p192_cmovznz_u32(&x3, arg1, (arg2[2]), (arg3[2]));
  uint32_t x4;
  fiat_p192_cmovznz_u32(&x4, arg1, (arg2[3]), (arg3[3]));
  uint32_t x5;
  fiat_p192_cmovznz_u32(&x5, arg1, (arg2[4]), (arg3[4]));
  uint32_t x6;
  fiat_p192_cmovznz_u32(&x6, arg1, (arg2[5]), (arg3[5]));
  uint32_t x7;
  fiat_p192_cmovznz_u32(&x7, arg1, (arg2[6]), (arg3[6]));
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
}

/*
 * The function fiat_p192_to_bytes serializes a field element to bytes in little-endian order.
 * Postconditions:
 *   out1 = map (λ x, ⌊((eval arg1 mod m) mod 2^(8 * (x + 1))) / 2^(8 * x)⌋) [0..23]
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x8cccccc]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff]]
 */
static void fiat_p192_to_bytes(uint8_t out1[24], const uint32_t arg1[7]) {
  uint32_t x1;
  fiat_p192_uint1 x2;
  fiat_p192_subborrowx_u28(&x1, &x2, 0x0, (arg1[0]), UINT32_C(0xfffffff));
  uint32_t x3;
  fiat_p192_uint1 x4;
  fiat_p192_subborrowx_u27(&x3, &x4, x2, (arg1[1]), UINT32_C(0x7ffffff));
  uint32_t x5;
  fiat_p192_uint1 x6;
  fiat_p192_subborrowx_u28(&x5, &x6, x4, (arg1[2]), UINT32_C(0xffffdff));
  uint32_t x7;
  fiat_p192_uint1 x8;
  fiat_p192_subborrowx_u27(&x7, &x8, x6, (arg1[3]), UINT32_C(0x7ffffff));
  uint32_t x9;
  fiat_p192_uint1 x10;
  fiat_p192_subborrowx_u28(&x9, &x10, x8, (arg1[4]), UINT32_C(0xfffffff));
  uint32_t x11;
  fiat_p192_uint1 x12;
  fiat_p192_subborrowx_u27(&x11, &x12, x10, (arg1[5]), UINT32_C(0x7ffffff));
  uint32_t x13;
  fiat_p192_uint1 x14;
  fiat_p192_subborrowx_u27(&x13, &x14, x12, (arg1[6]), UINT32_C(0x7ffffff));
  uint32_t x15;
  fiat_p192_cmovznz_u32(&x15, x14, 0x0, UINT32_C(0xffffffff));
  uint32_t x16;
  fiat_p192_uint1 x17;
  fiat_p192_addcarryx_u28(&x16, &x17, 0x0, x1, (x15 & UINT32_C(0xfffffff)));
  uint32_t x18;
  fiat_p192_uint1 x19;
  fiat_p192_addcarryx_u27(&x18, &x19, x17, x3, (x15 & UINT32_C(0x7ffffff)));
  uint32_t x20;
  fiat_p192_uint1 x21;
  fiat_p192_addcarryx_u28(&x20, &x21, x19, x5, (x15 & UINT32_C(0xffffdff)));
  uint32_t x22;
  fiat_p192_uint1 x23;
  fiat_p192_addcarryx_u27(&x22, &x23, x21, x7, (x15 & UINT32_C(0x7ffffff)));
  uint32_t x24;
  fiat_p192_uint1 x25;
  fiat_p192_addcarryx_u28(&x24, &x25, x23, x9, (x15 & UINT32_C(0xfffffff)));
  uint32_t x26;
  fiat_p192_uint1 x27;
  fiat_p192_addcarryx_u27(&x26, &x27, x25, x11, (x15 & UINT32_C(0x7ffffff)));
  uint32_t x28;
  fiat_p192_uint1 x29;
  fiat_p192_addcarryx_u27(&x28, &x29, x27, x13, (x15 & UINT32_C(0x7ffffff)));
  uint32_t x30 = (x28 << 5);
  uint32_t x31 = (x26 << 2);
  uint64_t x32 = ((uint64_t)x24 << 6);
  uint32_t x33 = (x22 << 3);
  uint64_t x34 = ((uint64_t)x20 << 7);
  uint32_t x35 = (x18 << 4);
  uint32_t x36 = (x16 >> 8);
  uint8_t x37 = (uint8_t)(x16 & UINT8_C(0xff));
  uint32_t x38 = (x36 >> 8);
  uint8_t x39 = (uint8_t)(x36 & UINT8_C(0xff));
  uint8_t x40 = (uint8_t)(x38 >> 8);
  uint8_t x41 = (uint8_t)(x38 & UINT8_C(0xff));
  uint32_t x42 = (x40 + x35);
  uint32_t x43 = (x42 >> 8);
  uint8_t x44 = (uint8_t)(x42 & UINT8_C(0xff));
  uint32_t x45 = (x43 >> 8);
  uint8_t x46 = (uint8_t)(x43 & UINT8_C(0xff));
  uint8_t x47 = (uint8_t)(x45 >> 8);
  uint8_t x48 = (uint8_t)(x45 & UINT8_C(0xff));
  uint64_t x49 = (x47 + x34);
  uint32_t x50 = (uint32_t)(x49 >> 8);
  uint8_t x51 = (uint8_t)(x49 & UINT8_C(0xff));
  uint32_t x52 = (x50 >> 8);
  uint8_t x53 = (uint8_t)(x50 & UINT8_C(0xff));
  uint32_t x54 = (x52 >> 8);
  uint8_t x55 = (uint8_t)(x52 & UINT8_C(0xff));
  uint8_t x56 = (uint8_t)(x54 >> 8);
  uint8_t x57 = (uint8_t)(x54 & UINT8_C(0xff));
  uint32_t x58 = (x56 + x33);
  uint32_t x59 = (x58 >> 8);
  uint8_t x60 = (uint8_t)(x58 & UINT8_C(0xff));
  uint32_t x61 = (x59 >> 8);
  uint8_t x62 = (uint8_t)(x59 & UINT8_C(0xff));
  uint8_t x63 = (uint8_t)(x61 >> 8);
  uint8_t x64 = (uint8_t)(x61 & UINT8_C(0xff));
  uint64_t x65 = (x63 + x32);
  uint32_t x66 = (uint32_t)(x65 >> 8);
  uint8_t x67 = (uint8_t)(x65 & UINT8_C(0xff));
  uint32_t x68 = (x66 >> 8);
  uint8_t x69 = (uint8_t)(x66 & UINT8_C(0xff));
  uint32_t x70 = (x68 >> 8);
  uint8_t x71 = (uint8_t)(x68 & UINT8_C(0xff));
  uint8_t x72 = (uint8_t)(x70 >> 8);
  uint8_t x73 = (uint8_t)(x70 & UINT8_C(0xff));
  uint32_t x74 = (x72 + x31);
  uint32_t x75 = (x74 >> 8);
  uint8_t x76 = (uint8_t)(x74 & UINT8_C(0xff));
  uint32_t x77 = (x75 >> 8);
  uint8_t x78 = (uint8_t)(x75 & UINT8_C(0xff));
  uint8_t x79 = (uint8_t)(x77 >> 8);
  uint8_t x80 = (uint8_t)(x77 & UINT8_C(0xff));
  uint32_t x81 = (x79 + x30);
  uint32_t x82 = (x81 >> 8);
  uint8_t x83 = (uint8_t)(x81 & UINT8_C(0xff));
  uint32_t x84 = (x82 >> 8);
  uint8_t x85 = (uint8_t)(x82 & UINT8_C(0xff));
  uint8_t x86 = (uint8_t)(x84 >> 8);
  uint8_t x87 = (uint8_t)(x84 & UINT8_C(0xff));
  out1[0] = x37;
  out1[1] = x39;
  out1[2] = x41;
  out1[3] = x44;
  out1[4] = x46;
  out1[5] = x48;
  out1[6] = x51;
  out1[7] = x53;
  out1[8] = x55;
  out1[9] = x57;
  out1[10] = x60;
  out1[11] = x62;
  out1[12] = x64;
  out1[13] = x67;
  out1[14] = x69;
  out1[15] = x71;
  out1[16] = x73;
  out1[17] = x76;
  out1[18] = x78;
  out1[19] = x80;
  out1[20] = x83;
  out1[21] = x85;
  out1[22] = x87;
  out1[23] = x86;
}

/*
 * The function fiat_p192_from_bytes deserializes a field element from bytes in little-endian order.
 * Postconditions:
 *   eval out1 mod m = bytes_eval arg1 mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x11999999], [0x0 ~> 0x8cccccc], [0x0 ~> 0x8cccccc]]
 */
static void fiat_p192_from_bytes(uint32_t out1[7], const uint8_t arg1[24]) {
  uint32_t x1 = ((uint32_t)(arg1[23]) << 19);
  uint32_t x2 = ((uint32_t)(arg1[22]) << 11);
  uint32_t x3 = ((uint32_t)(arg1[21]) << 3);
  uint32_t x4 = ((uint32_t)(arg1[20]) << 22);
  uint32_t x5 = ((uint32_t)(arg1[19]) << 14);
  uint32_t x6 = ((uint32_t)(arg1[18]) << 6);
  uint64_t x7 = ((uint64_t)(arg1[17]) << 26);
  uint32_t x8 = ((uint32_t)(arg1[16]) << 18);
  uint32_t x9 = ((uint32_t)(arg1[15]) << 10);
  uint32_t x10 = ((uint32_t)(arg1[14]) << 2);
  uint32_t x11 = ((uint32_t)(arg1[13]) << 21);
  uint32_t x12 = ((uint32_t)(arg1[12]) << 13);
  uint32_t x13 = ((uint32_t)(arg1[11]) << 5);
  uint64_t x14 = ((uint64_t)(arg1[10]) << 25);
  uint32_t x15 = ((uint32_t)(arg1[9]) << 17);
  uint32_t x16 = ((uint32_t)(arg1[8]) << 9);
  uint32_t x17 = ((uint32_t)(arg1[7]) * 0x2);
  uint32_t x18 = ((uint32_t)(arg1[6]) << 20);
  uint32_t x19 = ((uint32_t)(arg1[5]) << 12);
  uint32_t x20 = ((uint32_t)(arg1[4]) << 4);
  uint32_t x21 = ((uint32_t)(arg1[3]) << 24);
  uint32_t x22 = ((uint32_t)(arg1[2]) << 16);
  uint32_t x23 = ((uint32_t)(arg1[1]) << 8);
  uint8_t x24 = (arg1[0]);
  uint32_t x25 = (x24 + (x23 + (x22 + x21)));
  uint8_t x26 = (uint8_t)(x25 >> 28);
  uint32_t x27 = (x25 & UINT32_C(0xfffffff));
  uint32_t x28 = (x3 + (x2 + x1));
  uint32_t x29 = (x6 + (x5 + x4));
  uint64_t x30 = (x10 + (x9 + (x8 + x7)));
  uint32_t x31 = (x13 + (x12 + x11));
  uint64_t x32 = (x17 + (x16 + (x15 + x14)));
  uint32_t x33 = (x20 + (x19 + x18));
  uint32_t x34 = (x26 + x33);
  fiat_p192_uint1 x35 = (fiat_p192_uint1)(x34 >> 27);
  uint32_t x36 = (x34 & UINT32_C(0x7ffffff));
  uint64_t x37 = (x35 + x32);
  uint8_t x38 = (uint8_t)(x37 >> 28);
  uint32_t x39 = (uint32_t)(x37 & UINT32_C(0xfffffff));
  uint32_t x40 = (x38 + x31);
  uint8_t x41 = (uint8_t)(x40 >> 27);
  uint32_t x42 = (x40 & UINT32_C(0x7ffffff));
  uint64_t x43 = (x41 + x30);
  uint8_t x44 = (uint8_t)(x43 >> 28);
  uint32_t x45 = (uint32_t)(x43 & UINT32_C(0xfffffff));
  uint32_t x46 = (x44 + x29);
  uint8_t x47 = (uint8_t)(x46 >> 27);
  uint32_t x48 = (x46 & UINT32_C(0x7ffffff));
  uint32_t x49 = (x47 + x28);
  out1[0] = x27;
  out1[1] = x36;
  out1[2] = x39;
  out1[3] = x42;
  out1[4] = x45;
  out1[5] = x48;
  out1[6] = x49;
}

