/* Autogenerated */
/* curve description: p521 */
/* requested operations: (all) */
/* n = 18 (from "18") */
/* s-c = 2^521 - [(1, 1)] (from "2^521 - 1") */
/* machine_wordsize = 32 (from "32") */

/* Computed values: */
/* carry_chain = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 0, 1] */

#include <stdint.h>
typedef unsigned char fiat_p521_uint1;
typedef signed char fiat_p521_int1;
typedef signed __int128 fiat_p521_int128;
typedef unsigned __int128 fiat_p521_uint128;

#if (-1 & 3) != 3
#error "This code only works on a two's complement system"
#endif


/*
 * The function fiat_p521_addcarryx_u28 is an addition with carry.
 * Postconditions:
 *   out1 = (arg1 + arg2 + arg3) mod 2^28
 *   out2 = ⌊(arg1 + arg2 + arg3) / 2^28⌋
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [0x0 ~> 0xfffffff]
 *   arg3: [0x0 ~> 0xfffffff]
 * Output Bounds:
 *   out1: [0x0 ~> 0xfffffff]
 *   out2: [0x0 ~> 0x1]
 */
static void fiat_p521_addcarryx_u28(uint32_t* out1, fiat_p521_uint1* out2, fiat_p521_uint1 arg1, uint32_t arg2, uint32_t arg3) {
  uint32_t x1 = ((arg1 + arg2) + arg3);
  uint32_t x2 = (x1 & UINT32_C(0xfffffff));
  fiat_p521_uint1 x3 = (fiat_p521_uint1)(x1 >> 28);
  *out1 = x2;
  *out2 = x3;
}

/*
 * The function fiat_p521_subborrowx_u28 is a subtraction with borrow.
 * Postconditions:
 *   out1 = (-arg1 + arg2 + -arg3) mod 2^28
 *   out2 = -⌊(-arg1 + arg2 + -arg3) / 2^28⌋
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [0x0 ~> 0xfffffff]
 *   arg3: [0x0 ~> 0xfffffff]
 * Output Bounds:
 *   out1: [0x0 ~> 0xfffffff]
 *   out2: [0x0 ~> 0x1]
 */
static void fiat_p521_subborrowx_u28(uint32_t* out1, fiat_p521_uint1* out2, fiat_p521_uint1 arg1, uint32_t arg2, uint32_t arg3) {
  int32_t x1 = ((int32_t)(arg2 - arg1) - (int32_t)arg3);
  fiat_p521_int1 x2 = (fiat_p521_int1)(x1 >> 28);
  uint32_t x3 = (x1 & UINT32_C(0xfffffff));
  *out1 = x3;
  *out2 = (fiat_p521_uint1)(0x0 - x2);
}

/*
 * The function fiat_p521_addcarryx_u29 is an addition with carry.
 * Postconditions:
 *   out1 = (arg1 + arg2 + arg3) mod 2^29
 *   out2 = ⌊(arg1 + arg2 + arg3) / 2^29⌋
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [0x0 ~> 0x1fffffff]
 *   arg3: [0x0 ~> 0x1fffffff]
 * Output Bounds:
 *   out1: [0x0 ~> 0x1fffffff]
 *   out2: [0x0 ~> 0x1]
 */
static void fiat_p521_addcarryx_u29(uint32_t* out1, fiat_p521_uint1* out2, fiat_p521_uint1 arg1, uint32_t arg2, uint32_t arg3) {
  uint32_t x1 = ((arg1 + arg2) + arg3);
  uint32_t x2 = (x1 & UINT32_C(0x1fffffff));
  fiat_p521_uint1 x3 = (fiat_p521_uint1)(x1 >> 29);
  *out1 = x2;
  *out2 = x3;
}

/*
 * The function fiat_p521_subborrowx_u29 is a subtraction with borrow.
 * Postconditions:
 *   out1 = (-arg1 + arg2 + -arg3) mod 2^29
 *   out2 = -⌊(-arg1 + arg2 + -arg3) / 2^29⌋
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [0x0 ~> 0x1fffffff]
 *   arg3: [0x0 ~> 0x1fffffff]
 * Output Bounds:
 *   out1: [0x0 ~> 0x1fffffff]
 *   out2: [0x0 ~> 0x1]
 */
static void fiat_p521_subborrowx_u29(uint32_t* out1, fiat_p521_uint1* out2, fiat_p521_uint1 arg1, uint32_t arg2, uint32_t arg3) {
  int32_t x1 = ((int32_t)(arg2 - arg1) - (int32_t)arg3);
  fiat_p521_int1 x2 = (fiat_p521_int1)(x1 >> 29);
  uint32_t x3 = (x1 & UINT32_C(0x1fffffff));
  *out1 = x3;
  *out2 = (fiat_p521_uint1)(0x0 - x2);
}

/*
 * The function fiat_p521_cmovznz_u32 is a single-word conditional move.
 * Postconditions:
 *   out1 = (if arg1 = 0 then arg2 else arg3)
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [0x0 ~> 0xffffffff]
 *   arg3: [0x0 ~> 0xffffffff]
 * Output Bounds:
 *   out1: [0x0 ~> 0xffffffff]
 */
static void fiat_p521_cmovznz_u32(uint32_t* out1, fiat_p521_uint1 arg1, uint32_t arg2, uint32_t arg3) {
  fiat_p521_uint1 x1 = (!(!arg1));
  uint32_t x2 = ((fiat_p521_int1)(0x0 - x1) & UINT32_C(0xffffffff));
  uint32_t x3 = ((x2 & arg3) | ((~x2) & arg2));
  *out1 = x3;
}

/*
 * The function fiat_p521_carry_mul multiplies two field elements and reduces the result.
 * Postconditions:
 *   eval out1 mod m = (eval arg1 * eval arg2) mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x34cccccb]]
 *   arg2: [[0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x34cccccb]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x11999999]]
 */
static void fiat_p521_carry_mul(uint32_t out1[18], const uint32_t arg1[18], const uint32_t arg2[18]) {
  uint64_t x1 = ((uint64_t)(arg1[17]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x2 = ((uint64_t)(arg1[17]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x3 = ((uint64_t)(arg1[17]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x4 = ((uint64_t)(arg1[17]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x5 = ((uint64_t)(arg1[17]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x6 = ((uint64_t)(arg1[17]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x7 = ((uint64_t)(arg1[17]) * ((arg2[11]) * (uint32_t)0x2));
  uint64_t x8 = ((uint64_t)(arg1[17]) * ((arg2[10]) * (uint32_t)0x2));
  uint64_t x9 = ((uint64_t)(arg1[17]) * ((arg2[9]) * (uint32_t)0x2));
  uint64_t x10 = ((uint64_t)(arg1[17]) * ((arg2[8]) * (uint32_t)0x2));
  uint64_t x11 = ((uint64_t)(arg1[17]) * ((arg2[7]) * (uint32_t)0x2));
  uint64_t x12 = ((uint64_t)(arg1[17]) * ((arg2[6]) * (uint32_t)0x2));
  uint64_t x13 = ((uint64_t)(arg1[17]) * ((arg2[5]) * (uint32_t)0x2));
  uint64_t x14 = ((uint64_t)(arg1[17]) * ((arg2[4]) * (uint32_t)0x2));
  uint64_t x15 = ((uint64_t)(arg1[17]) * ((arg2[3]) * (uint32_t)0x2));
  uint64_t x16 = ((uint64_t)(arg1[17]) * ((arg2[2]) * (uint32_t)0x2));
  uint64_t x17 = ((uint64_t)(arg1[17]) * ((arg2[1]) * (uint32_t)0x2));
  uint64_t x18 = ((uint64_t)(arg1[16]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x19 = ((uint64_t)(arg1[16]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x20 = ((uint64_t)(arg1[16]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x21 = ((uint64_t)(arg1[16]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x22 = ((uint64_t)(arg1[16]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x23 = ((uint64_t)(arg1[16]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x24 = ((uint64_t)(arg1[16]) * ((arg2[11]) * (uint32_t)0x2));
  uint64_t x25 = ((uint64_t)(arg1[16]) * ((arg2[10]) * (uint32_t)0x2));
  uint64_t x26 = ((uint64_t)(arg1[16]) * ((arg2[9]) * (uint32_t)0x2));
  uint64_t x27 = ((uint64_t)(arg1[16]) * ((arg2[8]) * (uint32_t)0x2));
  uint64_t x28 = ((uint64_t)(arg1[16]) * ((arg2[7]) * (uint32_t)0x2));
  uint64_t x29 = ((uint64_t)(arg1[16]) * ((arg2[6]) * (uint32_t)0x2));
  uint64_t x30 = ((uint64_t)(arg1[16]) * ((arg2[5]) * (uint32_t)0x2));
  uint64_t x31 = ((uint64_t)(arg1[16]) * ((arg2[4]) * (uint32_t)0x2));
  uint64_t x32 = ((uint64_t)(arg1[16]) * ((arg2[3]) * (uint32_t)0x2));
  uint64_t x33 = ((uint64_t)(arg1[16]) * ((arg2[2]) * (uint32_t)0x2));
  uint64_t x34 = ((uint64_t)(arg1[15]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x35 = ((uint64_t)(arg1[15]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x36 = ((uint64_t)(arg1[15]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x37 = ((uint64_t)(arg1[15]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x38 = ((uint64_t)(arg1[15]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x39 = ((uint64_t)(arg1[15]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x40 = ((uint64_t)(arg1[15]) * ((arg2[11]) * (uint32_t)0x2));
  uint64_t x41 = ((uint64_t)(arg1[15]) * ((arg2[10]) * (uint32_t)0x2));
  uint64_t x42 = ((uint64_t)(arg1[15]) * ((arg2[9]) * (uint32_t)0x2));
  uint64_t x43 = ((uint64_t)(arg1[15]) * ((arg2[8]) * (uint32_t)0x2));
  uint64_t x44 = ((uint64_t)(arg1[15]) * ((arg2[7]) * (uint32_t)0x2));
  uint64_t x45 = ((uint64_t)(arg1[15]) * ((arg2[6]) * (uint32_t)0x2));
  uint64_t x46 = ((uint64_t)(arg1[15]) * ((arg2[5]) * (uint32_t)0x2));
  uint64_t x47 = ((uint64_t)(arg1[15]) * ((arg2[4]) * (uint32_t)0x2));
  uint64_t x48 = ((uint64_t)(arg1[15]) * ((arg2[3]) * (uint32_t)0x2));
  uint64_t x49 = ((uint64_t)(arg1[14]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x50 = ((uint64_t)(arg1[14]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x51 = ((uint64_t)(arg1[14]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x52 = ((uint64_t)(arg1[14]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x53 = ((uint64_t)(arg1[14]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x54 = ((uint64_t)(arg1[14]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x55 = ((uint64_t)(arg1[14]) * ((arg2[11]) * (uint32_t)0x2));
  uint64_t x56 = ((uint64_t)(arg1[14]) * ((arg2[10]) * (uint32_t)0x2));
  uint64_t x57 = ((uint64_t)(arg1[14]) * ((arg2[9]) * (uint32_t)0x2));
  uint64_t x58 = ((uint64_t)(arg1[14]) * ((arg2[8]) * (uint32_t)0x2));
  uint64_t x59 = ((uint64_t)(arg1[14]) * ((arg2[7]) * (uint32_t)0x2));
  uint64_t x60 = ((uint64_t)(arg1[14]) * ((arg2[6]) * (uint32_t)0x2));
  uint64_t x61 = ((uint64_t)(arg1[14]) * ((arg2[5]) * (uint32_t)0x2));
  uint64_t x62 = ((uint64_t)(arg1[14]) * ((arg2[4]) * (uint32_t)0x2));
  uint64_t x63 = ((uint64_t)(arg1[13]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x64 = ((uint64_t)(arg1[13]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x65 = ((uint64_t)(arg1[13]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x66 = ((uint64_t)(arg1[13]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x67 = ((uint64_t)(arg1[13]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x68 = ((uint64_t)(arg1[13]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x69 = ((uint64_t)(arg1[13]) * ((arg2[11]) * (uint32_t)0x2));
  uint64_t x70 = ((uint64_t)(arg1[13]) * ((arg2[10]) * (uint32_t)0x2));
  uint64_t x71 = ((uint64_t)(arg1[13]) * ((arg2[9]) * (uint32_t)0x2));
  uint64_t x72 = ((uint64_t)(arg1[13]) * ((arg2[8]) * (uint32_t)0x2));
  uint64_t x73 = ((uint64_t)(arg1[13]) * ((arg2[7]) * (uint32_t)0x2));
  uint64_t x74 = ((uint64_t)(arg1[13]) * ((arg2[6]) * (uint32_t)0x2));
  uint64_t x75 = ((uint64_t)(arg1[13]) * ((arg2[5]) * (uint32_t)0x2));
  uint64_t x76 = ((uint64_t)(arg1[12]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x77 = ((uint64_t)(arg1[12]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x78 = ((uint64_t)(arg1[12]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x79 = ((uint64_t)(arg1[12]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x80 = ((uint64_t)(arg1[12]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x81 = ((uint64_t)(arg1[12]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x82 = ((uint64_t)(arg1[12]) * ((arg2[11]) * (uint32_t)0x2));
  uint64_t x83 = ((uint64_t)(arg1[12]) * ((arg2[10]) * (uint32_t)0x2));
  uint64_t x84 = ((uint64_t)(arg1[12]) * ((arg2[9]) * (uint32_t)0x2));
  uint64_t x85 = ((uint64_t)(arg1[12]) * ((arg2[8]) * (uint32_t)0x2));
  uint64_t x86 = ((uint64_t)(arg1[12]) * ((arg2[7]) * (uint32_t)0x2));
  uint64_t x87 = ((uint64_t)(arg1[12]) * ((arg2[6]) * (uint32_t)0x2));
  uint64_t x88 = ((uint64_t)(arg1[11]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x89 = ((uint64_t)(arg1[11]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x90 = ((uint64_t)(arg1[11]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x91 = ((uint64_t)(arg1[11]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x92 = ((uint64_t)(arg1[11]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x93 = ((uint64_t)(arg1[11]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x94 = ((uint64_t)(arg1[11]) * ((arg2[11]) * (uint32_t)0x2));
  uint64_t x95 = ((uint64_t)(arg1[11]) * ((arg2[10]) * (uint32_t)0x2));
  uint64_t x96 = ((uint64_t)(arg1[11]) * ((arg2[9]) * (uint32_t)0x2));
  uint64_t x97 = ((uint64_t)(arg1[11]) * ((arg2[8]) * (uint32_t)0x2));
  uint64_t x98 = ((uint64_t)(arg1[11]) * ((arg2[7]) * (uint32_t)0x2));
  uint64_t x99 = ((uint64_t)(arg1[10]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x100 = ((uint64_t)(arg1[10]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x101 = ((uint64_t)(arg1[10]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x102 = ((uint64_t)(arg1[10]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x103 = ((uint64_t)(arg1[10]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x104 = ((uint64_t)(arg1[10]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x105 = ((uint64_t)(arg1[10]) * ((arg2[11]) * (uint32_t)0x2));
  uint64_t x106 = ((uint64_t)(arg1[10]) * ((arg2[10]) * (uint32_t)0x2));
  uint64_t x107 = ((uint64_t)(arg1[10]) * ((arg2[9]) * (uint32_t)0x2));
  uint64_t x108 = ((uint64_t)(arg1[10]) * ((arg2[8]) * (uint32_t)0x2));
  uint64_t x109 = ((uint64_t)(arg1[9]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x110 = ((uint64_t)(arg1[9]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x111 = ((uint64_t)(arg1[9]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x112 = ((uint64_t)(arg1[9]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x113 = ((uint64_t)(arg1[9]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x114 = ((uint64_t)(arg1[9]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x115 = ((uint64_t)(arg1[9]) * ((arg2[11]) * (uint32_t)0x2));
  uint64_t x116 = ((uint64_t)(arg1[9]) * ((arg2[10]) * (uint32_t)0x2));
  uint64_t x117 = ((uint64_t)(arg1[9]) * ((arg2[9]) * (uint32_t)0x2));
  uint64_t x118 = ((uint64_t)(arg1[8]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x119 = ((uint64_t)(arg1[8]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x120 = ((uint64_t)(arg1[8]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x121 = ((uint64_t)(arg1[8]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x122 = ((uint64_t)(arg1[8]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x123 = ((uint64_t)(arg1[8]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x124 = ((uint64_t)(arg1[8]) * ((arg2[11]) * (uint32_t)0x2));
  uint64_t x125 = ((uint64_t)(arg1[8]) * ((arg2[10]) * (uint32_t)0x2));
  uint64_t x126 = ((uint64_t)(arg1[7]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x127 = ((uint64_t)(arg1[7]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x128 = ((uint64_t)(arg1[7]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x129 = ((uint64_t)(arg1[7]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x130 = ((uint64_t)(arg1[7]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x131 = ((uint64_t)(arg1[7]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x132 = ((uint64_t)(arg1[7]) * ((arg2[11]) * (uint32_t)0x2));
  uint64_t x133 = ((uint64_t)(arg1[6]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x134 = ((uint64_t)(arg1[6]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x135 = ((uint64_t)(arg1[6]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x136 = ((uint64_t)(arg1[6]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x137 = ((uint64_t)(arg1[6]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x138 = ((uint64_t)(arg1[6]) * ((arg2[12]) * (uint32_t)0x2));
  uint64_t x139 = ((uint64_t)(arg1[5]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x140 = ((uint64_t)(arg1[5]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x141 = ((uint64_t)(arg1[5]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x142 = ((uint64_t)(arg1[5]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x143 = ((uint64_t)(arg1[5]) * ((arg2[13]) * (uint32_t)0x2));
  uint64_t x144 = ((uint64_t)(arg1[4]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x145 = ((uint64_t)(arg1[4]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x146 = ((uint64_t)(arg1[4]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x147 = ((uint64_t)(arg1[4]) * ((arg2[14]) * (uint32_t)0x2));
  uint64_t x148 = ((uint64_t)(arg1[3]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x149 = ((uint64_t)(arg1[3]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x150 = ((uint64_t)(arg1[3]) * ((arg2[15]) * (uint32_t)0x2));
  uint64_t x151 = ((uint64_t)(arg1[2]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x152 = ((uint64_t)(arg1[2]) * ((arg2[16]) * (uint32_t)0x2));
  uint64_t x153 = ((uint64_t)(arg1[1]) * ((arg2[17]) * (uint32_t)0x2));
  uint64_t x154 = ((uint64_t)(arg1[17]) * (arg2[0]));
  uint64_t x155 = ((uint64_t)(arg1[16]) * (arg2[1]));
  uint64_t x156 = ((uint64_t)(arg1[16]) * (arg2[0]));
  uint64_t x157 = ((uint64_t)(arg1[15]) * (arg2[2]));
  uint64_t x158 = ((uint64_t)(arg1[15]) * (arg2[1]));
  uint64_t x159 = ((uint64_t)(arg1[15]) * (arg2[0]));
  uint64_t x160 = ((uint64_t)(arg1[14]) * (arg2[3]));
  uint64_t x161 = ((uint64_t)(arg1[14]) * (arg2[2]));
  uint64_t x162 = ((uint64_t)(arg1[14]) * (arg2[1]));
  uint64_t x163 = ((uint64_t)(arg1[14]) * (arg2[0]));
  uint64_t x164 = ((uint64_t)(arg1[13]) * (arg2[4]));
  uint64_t x165 = ((uint64_t)(arg1[13]) * (arg2[3]));
  uint64_t x166 = ((uint64_t)(arg1[13]) * (arg2[2]));
  uint64_t x167 = ((uint64_t)(arg1[13]) * (arg2[1]));
  uint64_t x168 = ((uint64_t)(arg1[13]) * (arg2[0]));
  uint64_t x169 = ((uint64_t)(arg1[12]) * (arg2[5]));
  uint64_t x170 = ((uint64_t)(arg1[12]) * (arg2[4]));
  uint64_t x171 = ((uint64_t)(arg1[12]) * (arg2[3]));
  uint64_t x172 = ((uint64_t)(arg1[12]) * (arg2[2]));
  uint64_t x173 = ((uint64_t)(arg1[12]) * (arg2[1]));
  uint64_t x174 = ((uint64_t)(arg1[12]) * (arg2[0]));
  uint64_t x175 = ((uint64_t)(arg1[11]) * (arg2[6]));
  uint64_t x176 = ((uint64_t)(arg1[11]) * (arg2[5]));
  uint64_t x177 = ((uint64_t)(arg1[11]) * (arg2[4]));
  uint64_t x178 = ((uint64_t)(arg1[11]) * (arg2[3]));
  uint64_t x179 = ((uint64_t)(arg1[11]) * (arg2[2]));
  uint64_t x180 = ((uint64_t)(arg1[11]) * (arg2[1]));
  uint64_t x181 = ((uint64_t)(arg1[11]) * (arg2[0]));
  uint64_t x182 = ((uint64_t)(arg1[10]) * (arg2[7]));
  uint64_t x183 = ((uint64_t)(arg1[10]) * (arg2[6]));
  uint64_t x184 = ((uint64_t)(arg1[10]) * (arg2[5]));
  uint64_t x185 = ((uint64_t)(arg1[10]) * (arg2[4]));
  uint64_t x186 = ((uint64_t)(arg1[10]) * (arg2[3]));
  uint64_t x187 = ((uint64_t)(arg1[10]) * (arg2[2]));
  uint64_t x188 = ((uint64_t)(arg1[10]) * (arg2[1]));
  uint64_t x189 = ((uint64_t)(arg1[10]) * (arg2[0]));
  uint64_t x190 = ((uint64_t)(arg1[9]) * (arg2[8]));
  uint64_t x191 = ((uint64_t)(arg1[9]) * (arg2[7]));
  uint64_t x192 = ((uint64_t)(arg1[9]) * (arg2[6]));
  uint64_t x193 = ((uint64_t)(arg1[9]) * (arg2[5]));
  uint64_t x194 = ((uint64_t)(arg1[9]) * (arg2[4]));
  uint64_t x195 = ((uint64_t)(arg1[9]) * (arg2[3]));
  uint64_t x196 = ((uint64_t)(arg1[9]) * (arg2[2]));
  uint64_t x197 = ((uint64_t)(arg1[9]) * (arg2[1]));
  uint64_t x198 = ((uint64_t)(arg1[9]) * (arg2[0]));
  uint64_t x199 = ((uint64_t)(arg1[8]) * (arg2[9]));
  uint64_t x200 = ((uint64_t)(arg1[8]) * (arg2[8]));
  uint64_t x201 = ((uint64_t)(arg1[8]) * (arg2[7]));
  uint64_t x202 = ((uint64_t)(arg1[8]) * (arg2[6]));
  uint64_t x203 = ((uint64_t)(arg1[8]) * (arg2[5]));
  uint64_t x204 = ((uint64_t)(arg1[8]) * (arg2[4]));
  uint64_t x205 = ((uint64_t)(arg1[8]) * (arg2[3]));
  uint64_t x206 = ((uint64_t)(arg1[8]) * (arg2[2]));
  uint64_t x207 = ((uint64_t)(arg1[8]) * (arg2[1]));
  uint64_t x208 = ((uint64_t)(arg1[8]) * (arg2[0]));
  uint64_t x209 = ((uint64_t)(arg1[7]) * (arg2[10]));
  uint64_t x210 = ((uint64_t)(arg1[7]) * (arg2[9]));
  uint64_t x211 = ((uint64_t)(arg1[7]) * (arg2[8]));
  uint64_t x212 = ((uint64_t)(arg1[7]) * (arg2[7]));
  uint64_t x213 = ((uint64_t)(arg1[7]) * (arg2[6]));
  uint64_t x214 = ((uint64_t)(arg1[7]) * (arg2[5]));
  uint64_t x215 = ((uint64_t)(arg1[7]) * (arg2[4]));
  uint64_t x216 = ((uint64_t)(arg1[7]) * (arg2[3]));
  uint64_t x217 = ((uint64_t)(arg1[7]) * (arg2[2]));
  uint64_t x218 = ((uint64_t)(arg1[7]) * (arg2[1]));
  uint64_t x219 = ((uint64_t)(arg1[7]) * (arg2[0]));
  uint64_t x220 = ((uint64_t)(arg1[6]) * (arg2[11]));
  uint64_t x221 = ((uint64_t)(arg1[6]) * (arg2[10]));
  uint64_t x222 = ((uint64_t)(arg1[6]) * (arg2[9]));
  uint64_t x223 = ((uint64_t)(arg1[6]) * (arg2[8]));
  uint64_t x224 = ((uint64_t)(arg1[6]) * (arg2[7]));
  uint64_t x225 = ((uint64_t)(arg1[6]) * (arg2[6]));
  uint64_t x226 = ((uint64_t)(arg1[6]) * (arg2[5]));
  uint64_t x227 = ((uint64_t)(arg1[6]) * (arg2[4]));
  uint64_t x228 = ((uint64_t)(arg1[6]) * (arg2[3]));
  uint64_t x229 = ((uint64_t)(arg1[6]) * (arg2[2]));
  uint64_t x230 = ((uint64_t)(arg1[6]) * (arg2[1]));
  uint64_t x231 = ((uint64_t)(arg1[6]) * (arg2[0]));
  uint64_t x232 = ((uint64_t)(arg1[5]) * (arg2[12]));
  uint64_t x233 = ((uint64_t)(arg1[5]) * (arg2[11]));
  uint64_t x234 = ((uint64_t)(arg1[5]) * (arg2[10]));
  uint64_t x235 = ((uint64_t)(arg1[5]) * (arg2[9]));
  uint64_t x236 = ((uint64_t)(arg1[5]) * (arg2[8]));
  uint64_t x237 = ((uint64_t)(arg1[5]) * (arg2[7]));
  uint64_t x238 = ((uint64_t)(arg1[5]) * (arg2[6]));
  uint64_t x239 = ((uint64_t)(arg1[5]) * (arg2[5]));
  uint64_t x240 = ((uint64_t)(arg1[5]) * (arg2[4]));
  uint64_t x241 = ((uint64_t)(arg1[5]) * (arg2[3]));
  uint64_t x242 = ((uint64_t)(arg1[5]) * (arg2[2]));
  uint64_t x243 = ((uint64_t)(arg1[5]) * (arg2[1]));
  uint64_t x244 = ((uint64_t)(arg1[5]) * (arg2[0]));
  uint64_t x245 = ((uint64_t)(arg1[4]) * (arg2[13]));
  uint64_t x246 = ((uint64_t)(arg1[4]) * (arg2[12]));
  uint64_t x247 = ((uint64_t)(arg1[4]) * (arg2[11]));
  uint64_t x248 = ((uint64_t)(arg1[4]) * (arg2[10]));
  uint64_t x249 = ((uint64_t)(arg1[4]) * (arg2[9]));
  uint64_t x250 = ((uint64_t)(arg1[4]) * (arg2[8]));
  uint64_t x251 = ((uint64_t)(arg1[4]) * (arg2[7]));
  uint64_t x252 = ((uint64_t)(arg1[4]) * (arg2[6]));
  uint64_t x253 = ((uint64_t)(arg1[4]) * (arg2[5]));
  uint64_t x254 = ((uint64_t)(arg1[4]) * (arg2[4]));
  uint64_t x255 = ((uint64_t)(arg1[4]) * (arg2[3]));
  uint64_t x256 = ((uint64_t)(arg1[4]) * (arg2[2]));
  uint64_t x257 = ((uint64_t)(arg1[4]) * (arg2[1]));
  uint64_t x258 = ((uint64_t)(arg1[4]) * (arg2[0]));
  uint64_t x259 = ((uint64_t)(arg1[3]) * (arg2[14]));
  uint64_t x260 = ((uint64_t)(arg1[3]) * (arg2[13]));
  uint64_t x261 = ((uint64_t)(arg1[3]) * (arg2[12]));
  uint64_t x262 = ((uint64_t)(arg1[3]) * (arg2[11]));
  uint64_t x263 = ((uint64_t)(arg1[3]) * (arg2[10]));
  uint64_t x264 = ((uint64_t)(arg1[3]) * (arg2[9]));
  uint64_t x265 = ((uint64_t)(arg1[3]) * (arg2[8]));
  uint64_t x266 = ((uint64_t)(arg1[3]) * (arg2[7]));
  uint64_t x267 = ((uint64_t)(arg1[3]) * (arg2[6]));
  uint64_t x268 = ((uint64_t)(arg1[3]) * (arg2[5]));
  uint64_t x269 = ((uint64_t)(arg1[3]) * (arg2[4]));
  uint64_t x270 = ((uint64_t)(arg1[3]) * (arg2[3]));
  uint64_t x271 = ((uint64_t)(arg1[3]) * (arg2[2]));
  uint64_t x272 = ((uint64_t)(arg1[3]) * (arg2[1]));
  uint64_t x273 = ((uint64_t)(arg1[3]) * (arg2[0]));
  uint64_t x274 = ((uint64_t)(arg1[2]) * (arg2[15]));
  uint64_t x275 = ((uint64_t)(arg1[2]) * (arg2[14]));
  uint64_t x276 = ((uint64_t)(arg1[2]) * (arg2[13]));
  uint64_t x277 = ((uint64_t)(arg1[2]) * (arg2[12]));
  uint64_t x278 = ((uint64_t)(arg1[2]) * (arg2[11]));
  uint64_t x279 = ((uint64_t)(arg1[2]) * (arg2[10]));
  uint64_t x280 = ((uint64_t)(arg1[2]) * (arg2[9]));
  uint64_t x281 = ((uint64_t)(arg1[2]) * (arg2[8]));
  uint64_t x282 = ((uint64_t)(arg1[2]) * (arg2[7]));
  uint64_t x283 = ((uint64_t)(arg1[2]) * (arg2[6]));
  uint64_t x284 = ((uint64_t)(arg1[2]) * (arg2[5]));
  uint64_t x285 = ((uint64_t)(arg1[2]) * (arg2[4]));
  uint64_t x286 = ((uint64_t)(arg1[2]) * (arg2[3]));
  uint64_t x287 = ((uint64_t)(arg1[2]) * (arg2[2]));
  uint64_t x288 = ((uint64_t)(arg1[2]) * (arg2[1]));
  uint64_t x289 = ((uint64_t)(arg1[2]) * (arg2[0]));
  uint64_t x290 = ((uint64_t)(arg1[1]) * (arg2[16]));
  uint64_t x291 = ((uint64_t)(arg1[1]) * (arg2[15]));
  uint64_t x292 = ((uint64_t)(arg1[1]) * (arg2[14]));
  uint64_t x293 = ((uint64_t)(arg1[1]) * (arg2[13]));
  uint64_t x294 = ((uint64_t)(arg1[1]) * (arg2[12]));
  uint64_t x295 = ((uint64_t)(arg1[1]) * (arg2[11]));
  uint64_t x296 = ((uint64_t)(arg1[1]) * (arg2[10]));
  uint64_t x297 = ((uint64_t)(arg1[1]) * (arg2[9]));
  uint64_t x298 = ((uint64_t)(arg1[1]) * (arg2[8]));
  uint64_t x299 = ((uint64_t)(arg1[1]) * (arg2[7]));
  uint64_t x300 = ((uint64_t)(arg1[1]) * (arg2[6]));
  uint64_t x301 = ((uint64_t)(arg1[1]) * (arg2[5]));
  uint64_t x302 = ((uint64_t)(arg1[1]) * (arg2[4]));
  uint64_t x303 = ((uint64_t)(arg1[1]) * (arg2[3]));
  uint64_t x304 = ((uint64_t)(arg1[1]) * (arg2[2]));
  uint64_t x305 = ((uint64_t)(arg1[1]) * (arg2[1]));
  uint64_t x306 = ((uint64_t)(arg1[1]) * (arg2[0]));
  uint64_t x307 = ((uint64_t)(arg1[0]) * (arg2[17]));
  uint64_t x308 = ((uint64_t)(arg1[0]) * (arg2[16]));
  uint64_t x309 = ((uint64_t)(arg1[0]) * (arg2[15]));
  uint64_t x310 = ((uint64_t)(arg1[0]) * (arg2[14]));
  uint64_t x311 = ((uint64_t)(arg1[0]) * (arg2[13]));
  uint64_t x312 = ((uint64_t)(arg1[0]) * (arg2[12]));
  uint64_t x313 = ((uint64_t)(arg1[0]) * (arg2[11]));
  uint64_t x314 = ((uint64_t)(arg1[0]) * (arg2[10]));
  uint64_t x315 = ((uint64_t)(arg1[0]) * (arg2[9]));
  uint64_t x316 = ((uint64_t)(arg1[0]) * (arg2[8]));
  uint64_t x317 = ((uint64_t)(arg1[0]) * (arg2[7]));
  uint64_t x318 = ((uint64_t)(arg1[0]) * (arg2[6]));
  uint64_t x319 = ((uint64_t)(arg1[0]) * (arg2[5]));
  uint64_t x320 = ((uint64_t)(arg1[0]) * (arg2[4]));
  uint64_t x321 = ((uint64_t)(arg1[0]) * (arg2[3]));
  uint64_t x322 = ((uint64_t)(arg1[0]) * (arg2[2]));
  uint64_t x323 = ((uint64_t)(arg1[0]) * (arg2[1]));
  uint64_t x324 = ((uint64_t)(arg1[0]) * (arg2[0]));
  fiat_p521_uint128 x325 = (x324 + (x153 + (x152 + (x150 + (x147 + (x143 + (x138 + (x132 + (x125 + (x117 + (x108 + (x98 + (x87 + (x75 + ((fiat_p521_uint128)x62 + (x48 + (x33 + x17)))))))))))))))));
  uint64_t x326 = (uint64_t)(x325 >> 29);
  uint32_t x327 = (uint32_t)(x325 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x328 = (x307 + (x290 + (x274 + (x259 + (x245 + (x232 + (x220 + (x209 + (x199 + (x190 + (x182 + ((fiat_p521_uint128)x175 + (x169 + (x164 + (x160 + (x157 + (x155 + x154)))))))))))))))));
  fiat_p521_uint128 x329 = (x308 + (x291 + (x275 + (x260 + (x246 + (x233 + (x221 + (x210 + (x200 + (x191 + (x183 + ((fiat_p521_uint128)x176 + (x170 + (x165 + (x161 + (x158 + (x156 + x1)))))))))))))))));
  fiat_p521_uint128 x330 = (x309 + (x292 + (x276 + (x261 + (x247 + (x234 + (x222 + (x211 + (x201 + (x192 + (x184 + (x177 + ((fiat_p521_uint128)x171 + (x166 + (x162 + (x159 + (x18 + x2)))))))))))))))));
  fiat_p521_uint128 x331 = (x310 + (x293 + (x277 + (x262 + (x248 + (x235 + (x223 + (x212 + (x202 + (x193 + (x185 + (x178 + (x172 + ((fiat_p521_uint128)x167 + (x163 + (x34 + (x19 + x3)))))))))))))))));
  fiat_p521_uint128 x332 = (x311 + (x294 + (x278 + (x263 + (x249 + (x236 + (x224 + (x213 + (x203 + (x194 + (x186 + (x179 + (x173 + (x168 + ((fiat_p521_uint128)x49 + (x35 + (x20 + x4)))))))))))))))));
  fiat_p521_uint128 x333 = (x312 + (x295 + (x279 + (x264 + (x250 + (x237 + (x225 + (x214 + (x204 + (x195 + (x187 + (x180 + (x174 + (x63 + ((fiat_p521_uint128)x50 + (x36 + (x21 + x5)))))))))))))))));
  fiat_p521_uint128 x334 = (x313 + (x296 + (x280 + (x265 + (x251 + (x238 + (x226 + (x215 + (x205 + (x196 + (x188 + (x181 + (x76 + (x64 + ((fiat_p521_uint128)x51 + (x37 + (x22 + x6)))))))))))))))));
  fiat_p521_uint128 x335 = (x314 + (x297 + (x281 + (x266 + (x252 + (x239 + (x227 + (x216 + (x206 + (x197 + (x189 + (x88 + (x77 + (x65 + ((fiat_p521_uint128)x52 + (x38 + (x23 + x7)))))))))))))))));
  fiat_p521_uint128 x336 = (x315 + (x298 + (x282 + (x267 + (x253 + (x240 + (x228 + (x217 + (x207 + (x198 + (x99 + (x89 + (x78 + (x66 + ((fiat_p521_uint128)x53 + (x39 + (x24 + x8)))))))))))))))));
  fiat_p521_uint128 x337 = (x316 + (x299 + (x283 + (x268 + (x254 + (x241 + (x229 + (x218 + (x208 + (x109 + (x100 + (x90 + (x79 + (x67 + ((fiat_p521_uint128)x54 + (x40 + (x25 + x9)))))))))))))))));
  fiat_p521_uint128 x338 = (x317 + (x300 + (x284 + (x269 + (x255 + (x242 + (x230 + (x219 + (x118 + (x110 + (x101 + (x91 + (x80 + (x68 + ((fiat_p521_uint128)x55 + (x41 + (x26 + x10)))))))))))))))));
  fiat_p521_uint128 x339 = (x318 + (x301 + (x285 + (x270 + (x256 + (x243 + (x231 + (x126 + (x119 + (x111 + (x102 + (x92 + (x81 + (x69 + ((fiat_p521_uint128)x56 + (x42 + (x27 + x11)))))))))))))))));
  fiat_p521_uint128 x340 = (x319 + (x302 + (x286 + (x271 + (x257 + (x244 + (x133 + (x127 + (x120 + (x112 + (x103 + (x93 + (x82 + (x70 + ((fiat_p521_uint128)x57 + (x43 + (x28 + x12)))))))))))))))));
  fiat_p521_uint128 x341 = (x320 + (x303 + (x287 + (x272 + (x258 + (x139 + (x134 + (x128 + (x121 + (x113 + (x104 + (x94 + (x83 + (x71 + ((fiat_p521_uint128)x58 + (x44 + (x29 + x13)))))))))))))))));
  fiat_p521_uint128 x342 = (x321 + (x304 + (x288 + (x273 + (x144 + (x140 + (x135 + (x129 + (x122 + (x114 + (x105 + (x95 + (x84 + (x72 + ((fiat_p521_uint128)x59 + (x45 + (x30 + x14)))))))))))))))));
  fiat_p521_uint128 x343 = (x322 + (x305 + (x289 + (x148 + (x145 + (x141 + (x136 + (x130 + (x123 + (x115 + (x106 + (x96 + (x85 + (x73 + ((fiat_p521_uint128)x60 + (x46 + (x31 + x15)))))))))))))))));
  fiat_p521_uint128 x344 = (x323 + (x306 + (x151 + (x149 + (x146 + (x142 + (x137 + (x131 + (x124 + (x116 + (x107 + (x97 + (x86 + (x74 + ((fiat_p521_uint128)x61 + (x47 + (x32 + x16)))))))))))))))));
  fiat_p521_uint128 x345 = (x326 + x344);
  uint64_t x346 = (uint64_t)(x345 >> 29);
  uint32_t x347 = (uint32_t)(x345 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x348 = (x346 + x343);
  uint64_t x349 = (uint64_t)(x348 >> 29);
  uint32_t x350 = (uint32_t)(x348 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x351 = (x349 + x342);
  uint64_t x352 = (uint64_t)(x351 >> 29);
  uint32_t x353 = (uint32_t)(x351 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x354 = (x352 + x341);
  uint64_t x355 = (uint64_t)(x354 >> 29);
  uint32_t x356 = (uint32_t)(x354 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x357 = (x355 + x340);
  uint64_t x358 = (uint64_t)(x357 >> 29);
  uint32_t x359 = (uint32_t)(x357 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x360 = (x358 + x339);
  uint64_t x361 = (uint64_t)(x360 >> 29);
  uint32_t x362 = (uint32_t)(x360 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x363 = (x361 + x338);
  uint64_t x364 = (uint64_t)(x363 >> 29);
  uint32_t x365 = (uint32_t)(x363 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x366 = (x364 + x337);
  uint64_t x367 = (uint64_t)(x366 >> 29);
  uint32_t x368 = (uint32_t)(x366 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x369 = (x367 + x336);
  uint64_t x370 = (uint64_t)(x369 >> 29);
  uint32_t x371 = (uint32_t)(x369 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x372 = (x370 + x335);
  uint64_t x373 = (uint64_t)(x372 >> 29);
  uint32_t x374 = (uint32_t)(x372 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x375 = (x373 + x334);
  uint64_t x376 = (uint64_t)(x375 >> 29);
  uint32_t x377 = (uint32_t)(x375 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x378 = (x376 + x333);
  uint64_t x379 = (uint64_t)(x378 >> 29);
  uint32_t x380 = (uint32_t)(x378 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x381 = (x379 + x332);
  uint64_t x382 = (uint64_t)(x381 >> 29);
  uint32_t x383 = (uint32_t)(x381 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x384 = (x382 + x331);
  uint64_t x385 = (uint64_t)(x384 >> 29);
  uint32_t x386 = (uint32_t)(x384 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x387 = (x385 + x330);
  uint64_t x388 = (uint64_t)(x387 >> 29);
  uint32_t x389 = (uint32_t)(x387 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x390 = (x388 + x329);
  uint64_t x391 = (uint64_t)(x390 >> 29);
  uint32_t x392 = (uint32_t)(x390 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x393 = (x391 + x328);
  uint64_t x394 = (uint64_t)(x393 >> 28);
  uint32_t x395 = (uint32_t)(x393 & UINT32_C(0xfffffff));
  uint64_t x396 = (x327 + x394);
  uint32_t x397 = (uint32_t)(x396 >> 29);
  uint32_t x398 = (uint32_t)(x396 & UINT32_C(0x1fffffff));
  uint32_t x399 = (x397 + x347);
  uint32_t x400 = (x399 >> 29);
  uint32_t x401 = (x399 & UINT32_C(0x1fffffff));
  uint32_t x402 = (x400 + x350);
  out1[0] = x398;
  out1[1] = x401;
  out1[2] = x402;
  out1[3] = x353;
  out1[4] = x356;
  out1[5] = x359;
  out1[6] = x362;
  out1[7] = x365;
  out1[8] = x368;
  out1[9] = x371;
  out1[10] = x374;
  out1[11] = x377;
  out1[12] = x380;
  out1[13] = x383;
  out1[14] = x386;
  out1[15] = x389;
  out1[16] = x392;
  out1[17] = x395;
}

/*
 * The function fiat_p521_carry_square squares a field element and reduces the result.
 * Postconditions:
 *   eval out1 mod m = (eval arg1 * eval arg1) mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x34cccccb]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x11999999]]
 */
static void fiat_p521_carry_square(uint32_t out1[18], const uint32_t arg1[18]) {
  uint32_t x1 = (arg1[17]);
  uint32_t x2 = (x1 * (uint32_t)0x2);
  uint32_t x3 = ((arg1[17]) * (uint32_t)0x2);
  uint32_t x4 = (arg1[16]);
  uint32_t x5 = (x4 * (uint32_t)0x2);
  uint32_t x6 = ((arg1[16]) * (uint32_t)0x2);
  uint32_t x7 = (arg1[15]);
  uint32_t x8 = (x7 * (uint32_t)0x2);
  uint32_t x9 = ((arg1[15]) * (uint32_t)0x2);
  uint32_t x10 = (arg1[14]);
  uint32_t x11 = (x10 * (uint32_t)0x2);
  uint32_t x12 = ((arg1[14]) * (uint32_t)0x2);
  uint32_t x13 = (arg1[13]);
  uint32_t x14 = (x13 * (uint32_t)0x2);
  uint32_t x15 = ((arg1[13]) * (uint32_t)0x2);
  uint32_t x16 = (arg1[12]);
  uint32_t x17 = (x16 * (uint32_t)0x2);
  uint32_t x18 = ((arg1[12]) * (uint32_t)0x2);
  uint32_t x19 = (arg1[11]);
  uint32_t x20 = (x19 * (uint32_t)0x2);
  uint32_t x21 = ((arg1[11]) * (uint32_t)0x2);
  uint32_t x22 = (arg1[10]);
  uint32_t x23 = (x22 * (uint32_t)0x2);
  uint32_t x24 = ((arg1[10]) * (uint32_t)0x2);
  uint32_t x25 = (arg1[9]);
  uint32_t x26 = ((arg1[9]) * (uint32_t)0x2);
  uint32_t x27 = ((arg1[8]) * (uint32_t)0x2);
  uint32_t x28 = ((arg1[7]) * (uint32_t)0x2);
  uint32_t x29 = ((arg1[6]) * (uint32_t)0x2);
  uint32_t x30 = ((arg1[5]) * (uint32_t)0x2);
  uint32_t x31 = ((arg1[4]) * (uint32_t)0x2);
  uint32_t x32 = ((arg1[3]) * (uint32_t)0x2);
  uint32_t x33 = ((arg1[2]) * (uint32_t)0x2);
  uint32_t x34 = ((arg1[1]) * (uint32_t)0x2);
  uint64_t x35 = ((uint64_t)(arg1[17]) * (x1 * (uint32_t)0x2));
  uint64_t x36 = ((uint64_t)(arg1[16]) * (x2 * (uint32_t)0x2));
  uint64_t x37 = ((uint64_t)(arg1[16]) * (x4 * (uint32_t)0x2));
  uint64_t x38 = ((uint64_t)(arg1[15]) * (x2 * (uint32_t)0x2));
  uint64_t x39 = ((arg1[15]) * (x5 * (uint64_t)0x2));
  uint64_t x40 = ((uint64_t)(arg1[15]) * (x7 * (uint32_t)0x2));
  uint64_t x41 = ((uint64_t)(arg1[14]) * (x2 * (uint32_t)0x2));
  uint64_t x42 = ((arg1[14]) * (x5 * (uint64_t)0x2));
  uint64_t x43 = ((arg1[14]) * (x8 * (uint64_t)0x2));
  uint64_t x44 = ((uint64_t)(arg1[14]) * (x10 * (uint32_t)0x2));
  uint64_t x45 = ((uint64_t)(arg1[13]) * (x2 * (uint32_t)0x2));
  uint64_t x46 = ((arg1[13]) * (x5 * (uint64_t)0x2));
  uint64_t x47 = ((arg1[13]) * (x8 * (uint64_t)0x2));
  uint64_t x48 = ((arg1[13]) * (x11 * (uint64_t)0x2));
  uint64_t x49 = ((uint64_t)(arg1[13]) * (x13 * (uint32_t)0x2));
  uint64_t x50 = ((uint64_t)(arg1[12]) * (x2 * (uint32_t)0x2));
  uint64_t x51 = ((arg1[12]) * (x5 * (uint64_t)0x2));
  uint64_t x52 = ((arg1[12]) * (x8 * (uint64_t)0x2));
  uint64_t x53 = ((arg1[12]) * (x11 * (uint64_t)0x2));
  uint64_t x54 = ((arg1[12]) * (x14 * (uint64_t)0x2));
  uint64_t x55 = ((uint64_t)(arg1[12]) * (x16 * (uint32_t)0x2));
  uint64_t x56 = ((uint64_t)(arg1[11]) * (x2 * (uint32_t)0x2));
  uint64_t x57 = ((arg1[11]) * (x5 * (uint64_t)0x2));
  uint64_t x58 = ((arg1[11]) * (x8 * (uint64_t)0x2));
  uint64_t x59 = ((arg1[11]) * (x11 * (uint64_t)0x2));
  uint64_t x60 = ((arg1[11]) * (x14 * (uint64_t)0x2));
  uint64_t x61 = ((arg1[11]) * (x17 * (uint64_t)0x2));
  uint64_t x62 = ((uint64_t)(arg1[11]) * (x19 * (uint32_t)0x2));
  uint64_t x63 = ((uint64_t)(arg1[10]) * (x2 * (uint32_t)0x2));
  uint64_t x64 = ((arg1[10]) * (x5 * (uint64_t)0x2));
  uint64_t x65 = ((arg1[10]) * (x8 * (uint64_t)0x2));
  uint64_t x66 = ((arg1[10]) * (x11 * (uint64_t)0x2));
  uint64_t x67 = ((arg1[10]) * (x14 * (uint64_t)0x2));
  uint64_t x68 = ((arg1[10]) * (x17 * (uint64_t)0x2));
  uint64_t x69 = ((arg1[10]) * (x20 * (uint64_t)0x2));
  uint64_t x70 = ((uint64_t)(arg1[10]) * (x22 * (uint32_t)0x2));
  uint64_t x71 = ((uint64_t)(arg1[9]) * (x2 * (uint32_t)0x2));
  uint64_t x72 = ((arg1[9]) * (x5 * (uint64_t)0x2));
  uint64_t x73 = ((arg1[9]) * (x8 * (uint64_t)0x2));
  uint64_t x74 = ((arg1[9]) * (x11 * (uint64_t)0x2));
  uint64_t x75 = ((arg1[9]) * (x14 * (uint64_t)0x2));
  uint64_t x76 = ((arg1[9]) * (x17 * (uint64_t)0x2));
  uint64_t x77 = ((arg1[9]) * (x20 * (uint64_t)0x2));
  uint64_t x78 = ((arg1[9]) * (x23 * (uint64_t)0x2));
  uint64_t x79 = ((uint64_t)(arg1[9]) * (x25 * (uint32_t)0x2));
  uint64_t x80 = ((uint64_t)(arg1[8]) * (x2 * (uint32_t)0x2));
  uint64_t x81 = ((arg1[8]) * (x5 * (uint64_t)0x2));
  uint64_t x82 = ((arg1[8]) * (x8 * (uint64_t)0x2));
  uint64_t x83 = ((arg1[8]) * (x11 * (uint64_t)0x2));
  uint64_t x84 = ((arg1[8]) * (x14 * (uint64_t)0x2));
  uint64_t x85 = ((arg1[8]) * (x17 * (uint64_t)0x2));
  uint64_t x86 = ((arg1[8]) * (x20 * (uint64_t)0x2));
  uint64_t x87 = ((arg1[8]) * (x23 * (uint64_t)0x2));
  uint64_t x88 = ((uint64_t)(arg1[8]) * x26);
  uint64_t x89 = ((uint64_t)(arg1[8]) * (arg1[8]));
  uint64_t x90 = ((uint64_t)(arg1[7]) * (x2 * (uint32_t)0x2));
  uint64_t x91 = ((arg1[7]) * (x5 * (uint64_t)0x2));
  uint64_t x92 = ((arg1[7]) * (x8 * (uint64_t)0x2));
  uint64_t x93 = ((arg1[7]) * (x11 * (uint64_t)0x2));
  uint64_t x94 = ((arg1[7]) * (x14 * (uint64_t)0x2));
  uint64_t x95 = ((arg1[7]) * (x17 * (uint64_t)0x2));
  uint64_t x96 = ((arg1[7]) * (x20 * (uint64_t)0x2));
  uint64_t x97 = ((uint64_t)(arg1[7]) * x24);
  uint64_t x98 = ((uint64_t)(arg1[7]) * x26);
  uint64_t x99 = ((uint64_t)(arg1[7]) * x27);
  uint64_t x100 = ((uint64_t)(arg1[7]) * (arg1[7]));
  uint64_t x101 = ((uint64_t)(arg1[6]) * (x2 * (uint32_t)0x2));
  uint64_t x102 = ((arg1[6]) * (x5 * (uint64_t)0x2));
  uint64_t x103 = ((arg1[6]) * (x8 * (uint64_t)0x2));
  uint64_t x104 = ((arg1[6]) * (x11 * (uint64_t)0x2));
  uint64_t x105 = ((arg1[6]) * (x14 * (uint64_t)0x2));
  uint64_t x106 = ((arg1[6]) * (x17 * (uint64_t)0x2));
  uint64_t x107 = ((uint64_t)(arg1[6]) * x21);
  uint64_t x108 = ((uint64_t)(arg1[6]) * x24);
  uint64_t x109 = ((uint64_t)(arg1[6]) * x26);
  uint64_t x110 = ((uint64_t)(arg1[6]) * x27);
  uint64_t x111 = ((uint64_t)(arg1[6]) * x28);
  uint64_t x112 = ((uint64_t)(arg1[6]) * (arg1[6]));
  uint64_t x113 = ((uint64_t)(arg1[5]) * (x2 * (uint32_t)0x2));
  uint64_t x114 = ((arg1[5]) * (x5 * (uint64_t)0x2));
  uint64_t x115 = ((arg1[5]) * (x8 * (uint64_t)0x2));
  uint64_t x116 = ((arg1[5]) * (x11 * (uint64_t)0x2));
  uint64_t x117 = ((arg1[5]) * (x14 * (uint64_t)0x2));
  uint64_t x118 = ((uint64_t)(arg1[5]) * x18);
  uint64_t x119 = ((uint64_t)(arg1[5]) * x21);
  uint64_t x120 = ((uint64_t)(arg1[5]) * x24);
  uint64_t x121 = ((uint64_t)(arg1[5]) * x26);
  uint64_t x122 = ((uint64_t)(arg1[5]) * x27);
  uint64_t x123 = ((uint64_t)(arg1[5]) * x28);
  uint64_t x124 = ((uint64_t)(arg1[5]) * x29);
  uint64_t x125 = ((uint64_t)(arg1[5]) * (arg1[5]));
  uint64_t x126 = ((uint64_t)(arg1[4]) * (x2 * (uint32_t)0x2));
  uint64_t x127 = ((arg1[4]) * (x5 * (uint64_t)0x2));
  uint64_t x128 = ((arg1[4]) * (x8 * (uint64_t)0x2));
  uint64_t x129 = ((arg1[4]) * (x11 * (uint64_t)0x2));
  uint64_t x130 = ((uint64_t)(arg1[4]) * x15);
  uint64_t x131 = ((uint64_t)(arg1[4]) * x18);
  uint64_t x132 = ((uint64_t)(arg1[4]) * x21);
  uint64_t x133 = ((uint64_t)(arg1[4]) * x24);
  uint64_t x134 = ((uint64_t)(arg1[4]) * x26);
  uint64_t x135 = ((uint64_t)(arg1[4]) * x27);
  uint64_t x136 = ((uint64_t)(arg1[4]) * x28);
  uint64_t x137 = ((uint64_t)(arg1[4]) * x29);
  uint64_t x138 = ((uint64_t)(arg1[4]) * x30);
  uint64_t x139 = ((uint64_t)(arg1[4]) * (arg1[4]));
  uint64_t x140 = ((uint64_t)(arg1[3]) * (x2 * (uint32_t)0x2));
  uint64_t x141 = ((arg1[3]) * (x5 * (uint64_t)0x2));
  uint64_t x142 = ((arg1[3]) * (x8 * (uint64_t)0x2));
  uint64_t x143 = ((uint64_t)(arg1[3]) * x12);
  uint64_t x144 = ((uint64_t)(arg1[3]) * x15);
  uint64_t x145 = ((uint64_t)(arg1[3]) * x18);
  uint64_t x146 = ((uint64_t)(arg1[3]) * x21);
  uint64_t x147 = ((uint64_t)(arg1[3]) * x24);
  uint64_t x148 = ((uint64_t)(arg1[3]) * x26);
  uint64_t x149 = ((uint64_t)(arg1[3]) * x27);
  uint64_t x150 = ((uint64_t)(arg1[3]) * x28);
  uint64_t x151 = ((uint64_t)(arg1[3]) * x29);
  uint64_t x152 = ((uint64_t)(arg1[3]) * x30);
  uint64_t x153 = ((uint64_t)(arg1[3]) * x31);
  uint64_t x154 = ((uint64_t)(arg1[3]) * (arg1[3]));
  uint64_t x155 = ((uint64_t)(arg1[2]) * (x2 * (uint32_t)0x2));
  uint64_t x156 = ((arg1[2]) * (x5 * (uint64_t)0x2));
  uint64_t x157 = ((uint64_t)(arg1[2]) * x9);
  uint64_t x158 = ((uint64_t)(arg1[2]) * x12);
  uint64_t x159 = ((uint64_t)(arg1[2]) * x15);
  uint64_t x160 = ((uint64_t)(arg1[2]) * x18);
  uint64_t x161 = ((uint64_t)(arg1[2]) * x21);
  uint64_t x162 = ((uint64_t)(arg1[2]) * x24);
  uint64_t x163 = ((uint64_t)(arg1[2]) * x26);
  uint64_t x164 = ((uint64_t)(arg1[2]) * x27);
  uint64_t x165 = ((uint64_t)(arg1[2]) * x28);
  uint64_t x166 = ((uint64_t)(arg1[2]) * x29);
  uint64_t x167 = ((uint64_t)(arg1[2]) * x30);
  uint64_t x168 = ((uint64_t)(arg1[2]) * x31);
  uint64_t x169 = ((uint64_t)(arg1[2]) * x32);
  uint64_t x170 = ((uint64_t)(arg1[2]) * (arg1[2]));
  uint64_t x171 = ((uint64_t)(arg1[1]) * (x2 * (uint32_t)0x2));
  uint64_t x172 = ((uint64_t)(arg1[1]) * x6);
  uint64_t x173 = ((uint64_t)(arg1[1]) * x9);
  uint64_t x174 = ((uint64_t)(arg1[1]) * x12);
  uint64_t x175 = ((uint64_t)(arg1[1]) * x15);
  uint64_t x176 = ((uint64_t)(arg1[1]) * x18);
  uint64_t x177 = ((uint64_t)(arg1[1]) * x21);
  uint64_t x178 = ((uint64_t)(arg1[1]) * x24);
  uint64_t x179 = ((uint64_t)(arg1[1]) * x26);
  uint64_t x180 = ((uint64_t)(arg1[1]) * x27);
  uint64_t x181 = ((uint64_t)(arg1[1]) * x28);
  uint64_t x182 = ((uint64_t)(arg1[1]) * x29);
  uint64_t x183 = ((uint64_t)(arg1[1]) * x30);
  uint64_t x184 = ((uint64_t)(arg1[1]) * x31);
  uint64_t x185 = ((uint64_t)(arg1[1]) * x32);
  uint64_t x186 = ((uint64_t)(arg1[1]) * x33);
  uint64_t x187 = ((uint64_t)(arg1[1]) * (arg1[1]));
  uint64_t x188 = ((uint64_t)(arg1[0]) * x3);
  uint64_t x189 = ((uint64_t)(arg1[0]) * x6);
  uint64_t x190 = ((uint64_t)(arg1[0]) * x9);
  uint64_t x191 = ((uint64_t)(arg1[0]) * x12);
  uint64_t x192 = ((uint64_t)(arg1[0]) * x15);
  uint64_t x193 = ((uint64_t)(arg1[0]) * x18);
  uint64_t x194 = ((uint64_t)(arg1[0]) * x21);
  uint64_t x195 = ((uint64_t)(arg1[0]) * x24);
  uint64_t x196 = ((uint64_t)(arg1[0]) * x26);
  uint64_t x197 = ((uint64_t)(arg1[0]) * x27);
  uint64_t x198 = ((uint64_t)(arg1[0]) * x28);
  uint64_t x199 = ((uint64_t)(arg1[0]) * x29);
  uint64_t x200 = ((uint64_t)(arg1[0]) * x30);
  uint64_t x201 = ((uint64_t)(arg1[0]) * x31);
  uint64_t x202 = ((uint64_t)(arg1[0]) * x32);
  uint64_t x203 = ((uint64_t)(arg1[0]) * x33);
  uint64_t x204 = ((uint64_t)(arg1[0]) * x34);
  uint64_t x205 = ((uint64_t)(arg1[0]) * (arg1[0]));
  fiat_p521_uint128 x206 = (x205 + (x171 + (x156 + (x142 + (x129 + (x117 + (x106 + (x96 + ((fiat_p521_uint128)x87 + x79)))))))));
  uint64_t x207 = (uint64_t)(x206 >> 29);
  uint32_t x208 = (uint32_t)(x206 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x209 = (x188 + (x172 + (x157 + (x143 + (x130 + (x118 + ((fiat_p521_uint128)x107 + (x97 + x88))))))));
  fiat_p521_uint128 x210 = (x189 + (x173 + (x158 + (x144 + (x131 + ((fiat_p521_uint128)x119 + (x108 + (x98 + (x89 + x35)))))))));
  fiat_p521_uint128 x211 = (x190 + (x174 + (x159 + (x145 + (x132 + (x120 + ((fiat_p521_uint128)x109 + (x99 + x36))))))));
  fiat_p521_uint128 x212 = (x191 + (x175 + (x160 + (x146 + (x133 + (x121 + ((fiat_p521_uint128)x110 + (x100 + (x38 + x37)))))))));
  fiat_p521_uint128 x213 = (x192 + (x176 + (x161 + (x147 + (x134 + (x122 + (x111 + ((fiat_p521_uint128)x41 + x39))))))));
  fiat_p521_uint128 x214 = (x193 + (x177 + (x162 + (x148 + (x135 + (x123 + (x112 + (x45 + ((fiat_p521_uint128)x42 + x40)))))))));
  fiat_p521_uint128 x215 = (x194 + (x178 + (x163 + (x149 + (x136 + (x124 + (x50 + ((fiat_p521_uint128)x46 + x43))))))));
  fiat_p521_uint128 x216 = (x195 + (x179 + (x164 + (x150 + (x137 + (x125 + (x56 + (x51 + ((fiat_p521_uint128)x47 + x44)))))))));
  fiat_p521_uint128 x217 = (x196 + (x180 + (x165 + (x151 + (x138 + (x63 + (x57 + ((fiat_p521_uint128)x52 + x48))))))));
  fiat_p521_uint128 x218 = (x197 + (x181 + (x166 + (x152 + (x139 + (x71 + (x64 + (x58 + ((fiat_p521_uint128)x53 + x49)))))))));
  fiat_p521_uint128 x219 = (x198 + (x182 + (x167 + (x153 + (x80 + (x72 + (x65 + ((fiat_p521_uint128)x59 + x54))))))));
  fiat_p521_uint128 x220 = (x199 + (x183 + (x168 + (x154 + (x90 + (x81 + (x73 + (x66 + ((fiat_p521_uint128)x60 + x55)))))))));
  fiat_p521_uint128 x221 = (x200 + (x184 + (x169 + (x101 + (x91 + (x82 + (x74 + ((fiat_p521_uint128)x67 + x61))))))));
  fiat_p521_uint128 x222 = (x201 + (x185 + (x170 + (x113 + (x102 + (x92 + (x83 + (x75 + ((fiat_p521_uint128)x68 + x62)))))))));
  fiat_p521_uint128 x223 = (x202 + (x186 + (x126 + (x114 + (x103 + (x93 + (x84 + ((fiat_p521_uint128)x76 + x69))))))));
  fiat_p521_uint128 x224 = (x203 + (x187 + (x140 + (x127 + (x115 + (x104 + (x94 + (x85 + ((fiat_p521_uint128)x77 + x70)))))))));
  fiat_p521_uint128 x225 = (x204 + (x155 + (x141 + (x128 + (x116 + (x105 + (x95 + ((fiat_p521_uint128)x86 + x78))))))));
  fiat_p521_uint128 x226 = (x207 + x225);
  uint64_t x227 = (uint64_t)(x226 >> 29);
  uint32_t x228 = (uint32_t)(x226 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x229 = (x227 + x224);
  uint64_t x230 = (uint64_t)(x229 >> 29);
  uint32_t x231 = (uint32_t)(x229 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x232 = (x230 + x223);
  uint64_t x233 = (uint64_t)(x232 >> 29);
  uint32_t x234 = (uint32_t)(x232 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x235 = (x233 + x222);
  uint64_t x236 = (uint64_t)(x235 >> 29);
  uint32_t x237 = (uint32_t)(x235 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x238 = (x236 + x221);
  uint64_t x239 = (uint64_t)(x238 >> 29);
  uint32_t x240 = (uint32_t)(x238 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x241 = (x239 + x220);
  uint64_t x242 = (uint64_t)(x241 >> 29);
  uint32_t x243 = (uint32_t)(x241 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x244 = (x242 + x219);
  uint64_t x245 = (uint64_t)(x244 >> 29);
  uint32_t x246 = (uint32_t)(x244 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x247 = (x245 + x218);
  uint64_t x248 = (uint64_t)(x247 >> 29);
  uint32_t x249 = (uint32_t)(x247 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x250 = (x248 + x217);
  uint64_t x251 = (uint64_t)(x250 >> 29);
  uint32_t x252 = (uint32_t)(x250 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x253 = (x251 + x216);
  uint64_t x254 = (uint64_t)(x253 >> 29);
  uint32_t x255 = (uint32_t)(x253 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x256 = (x254 + x215);
  uint64_t x257 = (uint64_t)(x256 >> 29);
  uint32_t x258 = (uint32_t)(x256 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x259 = (x257 + x214);
  uint64_t x260 = (uint64_t)(x259 >> 29);
  uint32_t x261 = (uint32_t)(x259 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x262 = (x260 + x213);
  uint64_t x263 = (uint64_t)(x262 >> 29);
  uint32_t x264 = (uint32_t)(x262 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x265 = (x263 + x212);
  uint64_t x266 = (uint64_t)(x265 >> 29);
  uint32_t x267 = (uint32_t)(x265 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x268 = (x266 + x211);
  uint64_t x269 = (uint64_t)(x268 >> 29);
  uint32_t x270 = (uint32_t)(x268 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x271 = (x269 + x210);
  uint64_t x272 = (uint64_t)(x271 >> 29);
  uint32_t x273 = (uint32_t)(x271 & UINT32_C(0x1fffffff));
  fiat_p521_uint128 x274 = (x272 + x209);
  uint64_t x275 = (uint64_t)(x274 >> 28);
  uint32_t x276 = (uint32_t)(x274 & UINT32_C(0xfffffff));
  uint64_t x277 = (x208 + x275);
  uint32_t x278 = (uint32_t)(x277 >> 29);
  uint32_t x279 = (uint32_t)(x277 & UINT32_C(0x1fffffff));
  uint32_t x280 = (x278 + x228);
  uint32_t x281 = (x280 >> 29);
  uint32_t x282 = (x280 & UINT32_C(0x1fffffff));
  uint32_t x283 = (x281 + x231);
  out1[0] = x279;
  out1[1] = x282;
  out1[2] = x283;
  out1[3] = x234;
  out1[4] = x237;
  out1[5] = x240;
  out1[6] = x243;
  out1[7] = x246;
  out1[8] = x249;
  out1[9] = x252;
  out1[10] = x255;
  out1[11] = x258;
  out1[12] = x261;
  out1[13] = x264;
  out1[14] = x267;
  out1[15] = x270;
  out1[16] = x273;
  out1[17] = x276;
}

/*
 * The function fiat_p521_carry reduces a field element.
 * Postconditions:
 *   eval out1 mod m = eval arg1 mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x34cccccb]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x11999999]]
 */
static void fiat_p521_carry(uint32_t out1[18], const uint32_t arg1[18]) {
  uint32_t x1 = (arg1[0]);
  uint32_t x2 = ((x1 >> 29) + (arg1[1]));
  uint32_t x3 = ((x2 >> 29) + (arg1[2]));
  uint32_t x4 = ((x3 >> 29) + (arg1[3]));
  uint32_t x5 = ((x4 >> 29) + (arg1[4]));
  uint32_t x6 = ((x5 >> 29) + (arg1[5]));
  uint32_t x7 = ((x6 >> 29) + (arg1[6]));
  uint32_t x8 = ((x7 >> 29) + (arg1[7]));
  uint32_t x9 = ((x8 >> 29) + (arg1[8]));
  uint32_t x10 = ((x9 >> 29) + (arg1[9]));
  uint32_t x11 = ((x10 >> 29) + (arg1[10]));
  uint32_t x12 = ((x11 >> 29) + (arg1[11]));
  uint32_t x13 = ((x12 >> 29) + (arg1[12]));
  uint32_t x14 = ((x13 >> 29) + (arg1[13]));
  uint32_t x15 = ((x14 >> 29) + (arg1[14]));
  uint32_t x16 = ((x15 >> 29) + (arg1[15]));
  uint32_t x17 = ((x16 >> 29) + (arg1[16]));
  uint32_t x18 = ((x17 >> 29) + (arg1[17]));
  uint32_t x19 = ((x1 & UINT32_C(0x1fffffff)) + (x18 >> 28));
  uint32_t x20 = ((x19 >> 29) + (x2 & UINT32_C(0x1fffffff)));
  uint32_t x21 = (x19 & UINT32_C(0x1fffffff));
  uint32_t x22 = (x20 & UINT32_C(0x1fffffff));
  uint32_t x23 = ((x20 >> 29) + (x3 & UINT32_C(0x1fffffff)));
  uint32_t x24 = (x4 & UINT32_C(0x1fffffff));
  uint32_t x25 = (x5 & UINT32_C(0x1fffffff));
  uint32_t x26 = (x6 & UINT32_C(0x1fffffff));
  uint32_t x27 = (x7 & UINT32_C(0x1fffffff));
  uint32_t x28 = (x8 & UINT32_C(0x1fffffff));
  uint32_t x29 = (x9 & UINT32_C(0x1fffffff));
  uint32_t x30 = (x10 & UINT32_C(0x1fffffff));
  uint32_t x31 = (x11 & UINT32_C(0x1fffffff));
  uint32_t x32 = (x12 & UINT32_C(0x1fffffff));
  uint32_t x33 = (x13 & UINT32_C(0x1fffffff));
  uint32_t x34 = (x14 & UINT32_C(0x1fffffff));
  uint32_t x35 = (x15 & UINT32_C(0x1fffffff));
  uint32_t x36 = (x16 & UINT32_C(0x1fffffff));
  uint32_t x37 = (x17 & UINT32_C(0x1fffffff));
  uint32_t x38 = (x18 & UINT32_C(0xfffffff));
  out1[0] = x21;
  out1[1] = x22;
  out1[2] = x23;
  out1[3] = x24;
  out1[4] = x25;
  out1[5] = x26;
  out1[6] = x27;
  out1[7] = x28;
  out1[8] = x29;
  out1[9] = x30;
  out1[10] = x31;
  out1[11] = x32;
  out1[12] = x33;
  out1[13] = x34;
  out1[14] = x35;
  out1[15] = x36;
  out1[16] = x37;
  out1[17] = x38;
}

/*
 * The function fiat_p521_add adds two field elements.
 * Postconditions:
 *   eval out1 mod m = (eval arg1 + eval arg2) mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x11999999]]
 *   arg2: [[0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x11999999]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x34cccccb]]
 */
static void fiat_p521_add(uint32_t out1[18], const uint32_t arg1[18], const uint32_t arg2[18]) {
  uint32_t x1 = ((arg1[0]) + (arg2[0]));
  uint32_t x2 = ((arg1[1]) + (arg2[1]));
  uint32_t x3 = ((arg1[2]) + (arg2[2]));
  uint32_t x4 = ((arg1[3]) + (arg2[3]));
  uint32_t x5 = ((arg1[4]) + (arg2[4]));
  uint32_t x6 = ((arg1[5]) + (arg2[5]));
  uint32_t x7 = ((arg1[6]) + (arg2[6]));
  uint32_t x8 = ((arg1[7]) + (arg2[7]));
  uint32_t x9 = ((arg1[8]) + (arg2[8]));
  uint32_t x10 = ((arg1[9]) + (arg2[9]));
  uint32_t x11 = ((arg1[10]) + (arg2[10]));
  uint32_t x12 = ((arg1[11]) + (arg2[11]));
  uint32_t x13 = ((arg1[12]) + (arg2[12]));
  uint32_t x14 = ((arg1[13]) + (arg2[13]));
  uint32_t x15 = ((arg1[14]) + (arg2[14]));
  uint32_t x16 = ((arg1[15]) + (arg2[15]));
  uint32_t x17 = ((arg1[16]) + (arg2[16]));
  uint32_t x18 = ((arg1[17]) + (arg2[17]));
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
  out1[7] = x8;
  out1[8] = x9;
  out1[9] = x10;
  out1[10] = x11;
  out1[11] = x12;
  out1[12] = x13;
  out1[13] = x14;
  out1[14] = x15;
  out1[15] = x16;
  out1[16] = x17;
  out1[17] = x18;
}

/*
 * The function fiat_p521_sub subtracts two field elements.
 * Postconditions:
 *   eval out1 mod m = (eval arg1 - eval arg2) mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x11999999]]
 *   arg2: [[0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x11999999]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x34cccccb]]
 */
static void fiat_p521_sub(uint32_t out1[18], const uint32_t arg1[18], const uint32_t arg2[18]) {
  uint32_t x1 = ((UINT32_C(0x3ffffffe) + (arg1[0])) - (arg2[0]));
  uint32_t x2 = ((UINT32_C(0x3ffffffe) + (arg1[1])) - (arg2[1]));
  uint32_t x3 = ((UINT32_C(0x3ffffffe) + (arg1[2])) - (arg2[2]));
  uint32_t x4 = ((UINT32_C(0x3ffffffe) + (arg1[3])) - (arg2[3]));
  uint32_t x5 = ((UINT32_C(0x3ffffffe) + (arg1[4])) - (arg2[4]));
  uint32_t x6 = ((UINT32_C(0x3ffffffe) + (arg1[5])) - (arg2[5]));
  uint32_t x7 = ((UINT32_C(0x3ffffffe) + (arg1[6])) - (arg2[6]));
  uint32_t x8 = ((UINT32_C(0x3ffffffe) + (arg1[7])) - (arg2[7]));
  uint32_t x9 = ((UINT32_C(0x3ffffffe) + (arg1[8])) - (arg2[8]));
  uint32_t x10 = ((UINT32_C(0x3ffffffe) + (arg1[9])) - (arg2[9]));
  uint32_t x11 = ((UINT32_C(0x3ffffffe) + (arg1[10])) - (arg2[10]));
  uint32_t x12 = ((UINT32_C(0x3ffffffe) + (arg1[11])) - (arg2[11]));
  uint32_t x13 = ((UINT32_C(0x3ffffffe) + (arg1[12])) - (arg2[12]));
  uint32_t x14 = ((UINT32_C(0x3ffffffe) + (arg1[13])) - (arg2[13]));
  uint32_t x15 = ((UINT32_C(0x3ffffffe) + (arg1[14])) - (arg2[14]));
  uint32_t x16 = ((UINT32_C(0x3ffffffe) + (arg1[15])) - (arg2[15]));
  uint32_t x17 = ((UINT32_C(0x3ffffffe) + (arg1[16])) - (arg2[16]));
  uint32_t x18 = ((UINT32_C(0x1ffffffe) + (arg1[17])) - (arg2[17]));
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
  out1[7] = x8;
  out1[8] = x9;
  out1[9] = x10;
  out1[10] = x11;
  out1[11] = x12;
  out1[12] = x13;
  out1[13] = x14;
  out1[14] = x15;
  out1[15] = x16;
  out1[16] = x17;
  out1[17] = x18;
}

/*
 * The function fiat_p521_opp negates a field element.
 * Postconditions:
 *   eval out1 mod m = -eval arg1 mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x11999999]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x69999999], [0x0 ~> 0x34cccccb]]
 */
static void fiat_p521_opp(uint32_t out1[18], const uint32_t arg1[18]) {
  uint32_t x1 = (UINT32_C(0x3ffffffe) - (arg1[0]));
  uint32_t x2 = (UINT32_C(0x3ffffffe) - (arg1[1]));
  uint32_t x3 = (UINT32_C(0x3ffffffe) - (arg1[2]));
  uint32_t x4 = (UINT32_C(0x3ffffffe) - (arg1[3]));
  uint32_t x5 = (UINT32_C(0x3ffffffe) - (arg1[4]));
  uint32_t x6 = (UINT32_C(0x3ffffffe) - (arg1[5]));
  uint32_t x7 = (UINT32_C(0x3ffffffe) - (arg1[6]));
  uint32_t x8 = (UINT32_C(0x3ffffffe) - (arg1[7]));
  uint32_t x9 = (UINT32_C(0x3ffffffe) - (arg1[8]));
  uint32_t x10 = (UINT32_C(0x3ffffffe) - (arg1[9]));
  uint32_t x11 = (UINT32_C(0x3ffffffe) - (arg1[10]));
  uint32_t x12 = (UINT32_C(0x3ffffffe) - (arg1[11]));
  uint32_t x13 = (UINT32_C(0x3ffffffe) - (arg1[12]));
  uint32_t x14 = (UINT32_C(0x3ffffffe) - (arg1[13]));
  uint32_t x15 = (UINT32_C(0x3ffffffe) - (arg1[14]));
  uint32_t x16 = (UINT32_C(0x3ffffffe) - (arg1[15]));
  uint32_t x17 = (UINT32_C(0x3ffffffe) - (arg1[16]));
  uint32_t x18 = (UINT32_C(0x1ffffffe) - (arg1[17]));
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
  out1[7] = x8;
  out1[8] = x9;
  out1[9] = x10;
  out1[10] = x11;
  out1[11] = x12;
  out1[12] = x13;
  out1[13] = x14;
  out1[14] = x15;
  out1[15] = x16;
  out1[16] = x17;
  out1[17] = x18;
}

/*
 * The function fiat_p521_selectznz is a multi-limb conditional select.
 * Postconditions:
 *   eval out1 = (if arg1 = 0 then eval arg2 else eval arg3)
 *
 * Input Bounds:
 *   arg1: [0x0 ~> 0x1]
 *   arg2: [[0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff]]
 *   arg3: [[0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff], [0x0 ~> 0xffffffff]]
 */
static void fiat_p521_selectznz(uint32_t out1[18], fiat_p521_uint1 arg1, const uint32_t arg2[18], const uint32_t arg3[18]) {
  uint32_t x1;
  fiat_p521_cmovznz_u32(&x1, arg1, (arg2[0]), (arg3[0]));
  uint32_t x2;
  fiat_p521_cmovznz_u32(&x2, arg1, (arg2[1]), (arg3[1]));
  uint32_t x3;
  fiat_p521_cmovznz_u32(&x3, arg1, (arg2[2]), (arg3[2]));
  uint32_t x4;
  fiat_p521_cmovznz_u32(&x4, arg1, (arg2[3]), (arg3[3]));
  uint32_t x5;
  fiat_p521_cmovznz_u32(&x5, arg1, (arg2[4]), (arg3[4]));
  uint32_t x6;
  fiat_p521_cmovznz_u32(&x6, arg1, (arg2[5]), (arg3[5]));
  uint32_t x7;
  fiat_p521_cmovznz_u32(&x7, arg1, (arg2[6]), (arg3[6]));
  uint32_t x8;
  fiat_p521_cmovznz_u32(&x8, arg1, (arg2[7]), (arg3[7]));
  uint32_t x9;
  fiat_p521_cmovznz_u32(&x9, arg1, (arg2[8]), (arg3[8]));
  uint32_t x10;
  fiat_p521_cmovznz_u32(&x10, arg1, (arg2[9]), (arg3[9]));
  uint32_t x11;
  fiat_p521_cmovznz_u32(&x11, arg1, (arg2[10]), (arg3[10]));
  uint32_t x12;
  fiat_p521_cmovznz_u32(&x12, arg1, (arg2[11]), (arg3[11]));
  uint32_t x13;
  fiat_p521_cmovznz_u32(&x13, arg1, (arg2[12]), (arg3[12]));
  uint32_t x14;
  fiat_p521_cmovznz_u32(&x14, arg1, (arg2[13]), (arg3[13]));
  uint32_t x15;
  fiat_p521_cmovznz_u32(&x15, arg1, (arg2[14]), (arg3[14]));
  uint32_t x16;
  fiat_p521_cmovznz_u32(&x16, arg1, (arg2[15]), (arg3[15]));
  uint32_t x17;
  fiat_p521_cmovznz_u32(&x17, arg1, (arg2[16]), (arg3[16]));
  uint32_t x18;
  fiat_p521_cmovznz_u32(&x18, arg1, (arg2[17]), (arg3[17]));
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
  out1[7] = x8;
  out1[8] = x9;
  out1[9] = x10;
  out1[10] = x11;
  out1[11] = x12;
  out1[12] = x13;
  out1[13] = x14;
  out1[14] = x15;
  out1[15] = x16;
  out1[16] = x17;
  out1[17] = x18;
}

/*
 * The function fiat_p521_to_bytes serializes a field element to bytes in little-endian order.
 * Postconditions:
 *   out1 = map (λ x, ⌊((eval arg1 mod m) mod 2^(8 * (x + 1))) / 2^(8 * x)⌋) [0..65]
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x11999999]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0x1]]
 */
static void fiat_p521_to_bytes(uint8_t out1[66], const uint32_t arg1[18]) {
  uint32_t x1;
  fiat_p521_uint1 x2;
  fiat_p521_subborrowx_u29(&x1, &x2, 0x0, (arg1[0]), UINT32_C(0x1fffffff));
  uint32_t x3;
  fiat_p521_uint1 x4;
  fiat_p521_subborrowx_u29(&x3, &x4, x2, (arg1[1]), UINT32_C(0x1fffffff));
  uint32_t x5;
  fiat_p521_uint1 x6;
  fiat_p521_subborrowx_u29(&x5, &x6, x4, (arg1[2]), UINT32_C(0x1fffffff));
  uint32_t x7;
  fiat_p521_uint1 x8;
  fiat_p521_subborrowx_u29(&x7, &x8, x6, (arg1[3]), UINT32_C(0x1fffffff));
  uint32_t x9;
  fiat_p521_uint1 x10;
  fiat_p521_subborrowx_u29(&x9, &x10, x8, (arg1[4]), UINT32_C(0x1fffffff));
  uint32_t x11;
  fiat_p521_uint1 x12;
  fiat_p521_subborrowx_u29(&x11, &x12, x10, (arg1[5]), UINT32_C(0x1fffffff));
  uint32_t x13;
  fiat_p521_uint1 x14;
  fiat_p521_subborrowx_u29(&x13, &x14, x12, (arg1[6]), UINT32_C(0x1fffffff));
  uint32_t x15;
  fiat_p521_uint1 x16;
  fiat_p521_subborrowx_u29(&x15, &x16, x14, (arg1[7]), UINT32_C(0x1fffffff));
  uint32_t x17;
  fiat_p521_uint1 x18;
  fiat_p521_subborrowx_u29(&x17, &x18, x16, (arg1[8]), UINT32_C(0x1fffffff));
  uint32_t x19;
  fiat_p521_uint1 x20;
  fiat_p521_subborrowx_u29(&x19, &x20, x18, (arg1[9]), UINT32_C(0x1fffffff));
  uint32_t x21;
  fiat_p521_uint1 x22;
  fiat_p521_subborrowx_u29(&x21, &x22, x20, (arg1[10]), UINT32_C(0x1fffffff));
  uint32_t x23;
  fiat_p521_uint1 x24;
  fiat_p521_subborrowx_u29(&x23, &x24, x22, (arg1[11]), UINT32_C(0x1fffffff));
  uint32_t x25;
  fiat_p521_uint1 x26;
  fiat_p521_subborrowx_u29(&x25, &x26, x24, (arg1[12]), UINT32_C(0x1fffffff));
  uint32_t x27;
  fiat_p521_uint1 x28;
  fiat_p521_subborrowx_u29(&x27, &x28, x26, (arg1[13]), UINT32_C(0x1fffffff));
  uint32_t x29;
  fiat_p521_uint1 x30;
  fiat_p521_subborrowx_u29(&x29, &x30, x28, (arg1[14]), UINT32_C(0x1fffffff));
  uint32_t x31;
  fiat_p521_uint1 x32;
  fiat_p521_subborrowx_u29(&x31, &x32, x30, (arg1[15]), UINT32_C(0x1fffffff));
  uint32_t x33;
  fiat_p521_uint1 x34;
  fiat_p521_subborrowx_u29(&x33, &x34, x32, (arg1[16]), UINT32_C(0x1fffffff));
  uint32_t x35;
  fiat_p521_uint1 x36;
  fiat_p521_subborrowx_u28(&x35, &x36, x34, (arg1[17]), UINT32_C(0xfffffff));
  uint32_t x37;
  fiat_p521_cmovznz_u32(&x37, x36, 0x0, UINT32_C(0xffffffff));
  uint32_t x38;
  fiat_p521_uint1 x39;
  fiat_p521_addcarryx_u29(&x38, &x39, 0x0, x1, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x40;
  fiat_p521_uint1 x41;
  fiat_p521_addcarryx_u29(&x40, &x41, x39, x3, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x42;
  fiat_p521_uint1 x43;
  fiat_p521_addcarryx_u29(&x42, &x43, x41, x5, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x44;
  fiat_p521_uint1 x45;
  fiat_p521_addcarryx_u29(&x44, &x45, x43, x7, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x46;
  fiat_p521_uint1 x47;
  fiat_p521_addcarryx_u29(&x46, &x47, x45, x9, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x48;
  fiat_p521_uint1 x49;
  fiat_p521_addcarryx_u29(&x48, &x49, x47, x11, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x50;
  fiat_p521_uint1 x51;
  fiat_p521_addcarryx_u29(&x50, &x51, x49, x13, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x52;
  fiat_p521_uint1 x53;
  fiat_p521_addcarryx_u29(&x52, &x53, x51, x15, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x54;
  fiat_p521_uint1 x55;
  fiat_p521_addcarryx_u29(&x54, &x55, x53, x17, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x56;
  fiat_p521_uint1 x57;
  fiat_p521_addcarryx_u29(&x56, &x57, x55, x19, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x58;
  fiat_p521_uint1 x59;
  fiat_p521_addcarryx_u29(&x58, &x59, x57, x21, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x60;
  fiat_p521_uint1 x61;
  fiat_p521_addcarryx_u29(&x60, &x61, x59, x23, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x62;
  fiat_p521_uint1 x63;
  fiat_p521_addcarryx_u29(&x62, &x63, x61, x25, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x64;
  fiat_p521_uint1 x65;
  fiat_p521_addcarryx_u29(&x64, &x65, x63, x27, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x66;
  fiat_p521_uint1 x67;
  fiat_p521_addcarryx_u29(&x66, &x67, x65, x29, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x68;
  fiat_p521_uint1 x69;
  fiat_p521_addcarryx_u29(&x68, &x69, x67, x31, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x70;
  fiat_p521_uint1 x71;
  fiat_p521_addcarryx_u29(&x70, &x71, x69, x33, (x37 & UINT32_C(0x1fffffff)));
  uint32_t x72;
  fiat_p521_uint1 x73;
  fiat_p521_addcarryx_u28(&x72, &x73, x71, x35, (x37 & UINT32_C(0xfffffff)));
  uint64_t x74 = ((uint64_t)x72 << 5);
  uint32_t x75 = (x68 << 3);
  uint64_t x76 = ((uint64_t)x66 << 6);
  uint32_t x77 = (x64 * (uint32_t)0x2);
  uint64_t x78 = ((uint64_t)x62 << 4);
  uint64_t x79 = ((uint64_t)x60 << 7);
  uint32_t x80 = (x58 << 2);
  uint64_t x81 = ((uint64_t)x56 << 5);
  uint32_t x82 = (x52 << 3);
  uint64_t x83 = ((uint64_t)x50 << 6);
  uint32_t x84 = (x48 * (uint32_t)0x2);
  uint64_t x85 = ((uint64_t)x46 << 4);
  uint64_t x86 = ((uint64_t)x44 << 7);
  uint32_t x87 = (x42 << 2);
  uint64_t x88 = ((uint64_t)x40 << 5);
  uint32_t x89 = (x38 >> 8);
  uint8_t x90 = (uint8_t)(x38 & UINT8_C(0xff));
  uint32_t x91 = (x89 >> 8);
  uint8_t x92 = (uint8_t)(x89 & UINT8_C(0xff));
  uint8_t x93 = (uint8_t)(x91 >> 8);
  uint8_t x94 = (uint8_t)(x91 & UINT8_C(0xff));
  uint64_t x95 = (x93 + x88);
  uint32_t x96 = (uint32_t)(x95 >> 8);
  uint8_t x97 = (uint8_t)(x95 & UINT8_C(0xff));
  uint32_t x98 = (x96 >> 8);
  uint8_t x99 = (uint8_t)(x96 & UINT8_C(0xff));
  uint32_t x100 = (x98 >> 8);
  uint8_t x101 = (uint8_t)(x98 & UINT8_C(0xff));
  uint8_t x102 = (uint8_t)(x100 >> 8);
  uint8_t x103 = (uint8_t)(x100 & UINT8_C(0xff));
  uint32_t x104 = (x102 + x87);
  uint32_t x105 = (x104 >> 8);
  uint8_t x106 = (uint8_t)(x104 & UINT8_C(0xff));
  uint32_t x107 = (x105 >> 8);
  uint8_t x108 = (uint8_t)(x105 & UINT8_C(0xff));
  uint8_t x109 = (uint8_t)(x107 >> 8);
  uint8_t x110 = (uint8_t)(x107 & UINT8_C(0xff));
  uint64_t x111 = (x109 + x86);
  uint32_t x112 = (uint32_t)(x111 >> 8);
  uint8_t x113 = (uint8_t)(x111 & UINT8_C(0xff));
  uint32_t x114 = (x112 >> 8);
  uint8_t x115 = (uint8_t)(x112 & UINT8_C(0xff));
  uint32_t x116 = (x114 >> 8);
  uint8_t x117 = (uint8_t)(x114 & UINT8_C(0xff));
  uint8_t x118 = (uint8_t)(x116 >> 8);
  uint8_t x119 = (uint8_t)(x116 & UINT8_C(0xff));
  uint64_t x120 = (x118 + x85);
  uint32_t x121 = (uint32_t)(x120 >> 8);
  uint8_t x122 = (uint8_t)(x120 & UINT8_C(0xff));
  uint32_t x123 = (x121 >> 8);
  uint8_t x124 = (uint8_t)(x121 & UINT8_C(0xff));
  uint32_t x125 = (x123 >> 8);
  uint8_t x126 = (uint8_t)(x123 & UINT8_C(0xff));
  fiat_p521_uint1 x127 = (fiat_p521_uint1)(x125 >> 8);
  uint8_t x128 = (uint8_t)(x125 & UINT8_C(0xff));
  uint32_t x129 = (x127 + x84);
  uint32_t x130 = (x129 >> 8);
  uint8_t x131 = (uint8_t)(x129 & UINT8_C(0xff));
  uint32_t x132 = (x130 >> 8);
  uint8_t x133 = (uint8_t)(x130 & UINT8_C(0xff));
  uint8_t x134 = (uint8_t)(x132 >> 8);
  uint8_t x135 = (uint8_t)(x132 & UINT8_C(0xff));
  uint64_t x136 = (x134 + x83);
  uint32_t x137 = (uint32_t)(x136 >> 8);
  uint8_t x138 = (uint8_t)(x136 & UINT8_C(0xff));
  uint32_t x139 = (x137 >> 8);
  uint8_t x140 = (uint8_t)(x137 & UINT8_C(0xff));
  uint32_t x141 = (x139 >> 8);
  uint8_t x142 = (uint8_t)(x139 & UINT8_C(0xff));
  uint8_t x143 = (uint8_t)(x141 >> 8);
  uint8_t x144 = (uint8_t)(x141 & UINT8_C(0xff));
  uint32_t x145 = (x143 + x82);
  uint32_t x146 = (x145 >> 8);
  uint8_t x147 = (uint8_t)(x145 & UINT8_C(0xff));
  uint32_t x148 = (x146 >> 8);
  uint8_t x149 = (uint8_t)(x146 & UINT8_C(0xff));
  uint8_t x150 = (uint8_t)(x148 >> 8);
  uint8_t x151 = (uint8_t)(x148 & UINT8_C(0xff));
  uint8_t x152 = (uint8_t)(x150 & UINT8_C(0xff));
  uint32_t x153 = (x54 >> 8);
  uint8_t x154 = (uint8_t)(x54 & UINT8_C(0xff));
  uint32_t x155 = (x153 >> 8);
  uint8_t x156 = (uint8_t)(x153 & UINT8_C(0xff));
  uint8_t x157 = (uint8_t)(x155 >> 8);
  uint8_t x158 = (uint8_t)(x155 & UINT8_C(0xff));
  uint64_t x159 = (x157 + x81);
  uint32_t x160 = (uint32_t)(x159 >> 8);
  uint8_t x161 = (uint8_t)(x159 & UINT8_C(0xff));
  uint32_t x162 = (x160 >> 8);
  uint8_t x163 = (uint8_t)(x160 & UINT8_C(0xff));
  uint32_t x164 = (x162 >> 8);
  uint8_t x165 = (uint8_t)(x162 & UINT8_C(0xff));
  uint8_t x166 = (uint8_t)(x164 >> 8);
  uint8_t x167 = (uint8_t)(x164 & UINT8_C(0xff));
  uint32_t x168 = (x166 + x80);
  uint32_t x169 = (x168 >> 8);
  uint8_t x170 = (uint8_t)(x168 & UINT8_C(0xff));
  uint32_t x171 = (x169 >> 8);
  uint8_t x172 = (uint8_t)(x169 & UINT8_C(0xff));
  uint8_t x173 = (uint8_t)(x171 >> 8);
  uint8_t x174 = (uint8_t)(x171 & UINT8_C(0xff));
  uint64_t x175 = (x173 + x79);
  uint32_t x176 = (uint32_t)(x175 >> 8);
  uint8_t x177 = (uint8_t)(x175 & UINT8_C(0xff));
  uint32_t x178 = (x176 >> 8);
  uint8_t x179 = (uint8_t)(x176 & UINT8_C(0xff));
  uint32_t x180 = (x178 >> 8);
  uint8_t x181 = (uint8_t)(x178 & UINT8_C(0xff));
  uint8_t x182 = (uint8_t)(x180 >> 8);
  uint8_t x183 = (uint8_t)(x180 & UINT8_C(0xff));
  uint64_t x184 = (x182 + x78);
  uint32_t x185 = (uint32_t)(x184 >> 8);
  uint8_t x186 = (uint8_t)(x184 & UINT8_C(0xff));
  uint32_t x187 = (x185 >> 8);
  uint8_t x188 = (uint8_t)(x185 & UINT8_C(0xff));
  uint32_t x189 = (x187 >> 8);
  uint8_t x190 = (uint8_t)(x187 & UINT8_C(0xff));
  fiat_p521_uint1 x191 = (fiat_p521_uint1)(x189 >> 8);
  uint8_t x192 = (uint8_t)(x189 & UINT8_C(0xff));
  uint32_t x193 = (x191 + x77);
  uint32_t x194 = (x193 >> 8);
  uint8_t x195 = (uint8_t)(x193 & UINT8_C(0xff));
  uint32_t x196 = (x194 >> 8);
  uint8_t x197 = (uint8_t)(x194 & UINT8_C(0xff));
  uint8_t x198 = (uint8_t)(x196 >> 8);
  uint8_t x199 = (uint8_t)(x196 & UINT8_C(0xff));
  uint64_t x200 = (x198 + x76);
  uint32_t x201 = (uint32_t)(x200 >> 8);
  uint8_t x202 = (uint8_t)(x200 & UINT8_C(0xff));
  uint32_t x203 = (x201 >> 8);
  uint8_t x204 = (uint8_t)(x201 & UINT8_C(0xff));
  uint32_t x205 = (x203 >> 8);
  uint8_t x206 = (uint8_t)(x203 & UINT8_C(0xff));
  uint8_t x207 = (uint8_t)(x205 >> 8);
  uint8_t x208 = (uint8_t)(x205 & UINT8_C(0xff));
  uint32_t x209 = (x207 + x75);
  uint32_t x210 = (x209 >> 8);
  uint8_t x211 = (uint8_t)(x209 & UINT8_C(0xff));
  uint32_t x212 = (x210 >> 8);
  uint8_t x213 = (uint8_t)(x210 & UINT8_C(0xff));
  uint8_t x214 = (uint8_t)(x212 >> 8);
  uint8_t x215 = (uint8_t)(x212 & UINT8_C(0xff));
  uint8_t x216 = (uint8_t)(x214 & UINT8_C(0xff));
  uint32_t x217 = (x70 >> 8);
  uint8_t x218 = (uint8_t)(x70 & UINT8_C(0xff));
  uint32_t x219 = (x217 >> 8);
  uint8_t x220 = (uint8_t)(x217 & UINT8_C(0xff));
  uint8_t x221 = (uint8_t)(x219 >> 8);
  uint8_t x222 = (uint8_t)(x219 & UINT8_C(0xff));
  uint64_t x223 = (x221 + x74);
  uint32_t x224 = (uint32_t)(x223 >> 8);
  uint8_t x225 = (uint8_t)(x223 & UINT8_C(0xff));
  uint32_t x226 = (x224 >> 8);
  uint8_t x227 = (uint8_t)(x224 & UINT8_C(0xff));
  uint32_t x228 = (x226 >> 8);
  uint8_t x229 = (uint8_t)(x226 & UINT8_C(0xff));
  fiat_p521_uint1 x230 = (fiat_p521_uint1)(x228 >> 8);
  uint8_t x231 = (uint8_t)(x228 & UINT8_C(0xff));
  out1[0] = x90;
  out1[1] = x92;
  out1[2] = x94;
  out1[3] = x97;
  out1[4] = x99;
  out1[5] = x101;
  out1[6] = x103;
  out1[7] = x106;
  out1[8] = x108;
  out1[9] = x110;
  out1[10] = x113;
  out1[11] = x115;
  out1[12] = x117;
  out1[13] = x119;
  out1[14] = x122;
  out1[15] = x124;
  out1[16] = x126;
  out1[17] = x128;
  out1[18] = x131;
  out1[19] = x133;
  out1[20] = x135;
  out1[21] = x138;
  out1[22] = x140;
  out1[23] = x142;
  out1[24] = x144;
  out1[25] = x147;
  out1[26] = x149;
  out1[27] = x151;
  out1[28] = x152;
  out1[29] = x154;
  out1[30] = x156;
  out1[31] = x158;
  out1[32] = x161;
  out1[33] = x163;
  out1[34] = x165;
  out1[35] = x167;
  out1[36] = x170;
  out1[37] = x172;
  out1[38] = x174;
  out1[39] = x177;
  out1[40] = x179;
  out1[41] = x181;
  out1[42] = x183;
  out1[43] = x186;
  out1[44] = x188;
  out1[45] = x190;
  out1[46] = x192;
  out1[47] = x195;
  out1[48] = x197;
  out1[49] = x199;
  out1[50] = x202;
  out1[51] = x204;
  out1[52] = x206;
  out1[53] = x208;
  out1[54] = x211;
  out1[55] = x213;
  out1[56] = x215;
  out1[57] = x216;
  out1[58] = x218;
  out1[59] = x220;
  out1[60] = x222;
  out1[61] = x225;
  out1[62] = x227;
  out1[63] = x229;
  out1[64] = x231;
  out1[65] = x230;
}

/*
 * The function fiat_p521_from_bytes deserializes a field element from bytes in little-endian order.
 * Postconditions:
 *   eval out1 mod m = bytes_eval arg1 mod m
 *
 * Input Bounds:
 *   arg1: [[0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0xff], [0x0 ~> 0x1]]
 * Output Bounds:
 *   out1: [[0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x23333333], [0x0 ~> 0x11999999]]
 */
static void fiat_p521_from_bytes(uint32_t out1[18], const uint8_t arg1[66]) {
  uint32_t x1 = ((uint32_t)(fiat_p521_uint1)(arg1[65]) << 27);
  uint32_t x2 = ((uint32_t)(arg1[64]) << 19);
  uint32_t x3 = ((uint32_t)(arg1[63]) << 11);
  uint32_t x4 = ((uint32_t)(arg1[62]) << 3);
  uint32_t x5 = ((uint32_t)(arg1[61]) << 24);
  uint32_t x6 = ((uint32_t)(arg1[60]) << 16);
  uint32_t x7 = ((uint32_t)(arg1[59]) << 8);
  uint8_t x8 = (arg1[58]);
  uint32_t x9 = ((uint32_t)(arg1[57]) << 21);
  uint32_t x10 = ((uint32_t)(arg1[56]) << 13);
  uint32_t x11 = ((uint32_t)(arg1[55]) << 5);
  uint64_t x12 = ((uint64_t)(arg1[54]) << 26);
  uint32_t x13 = ((uint32_t)(arg1[53]) << 18);
  uint32_t x14 = ((uint32_t)(arg1[52]) << 10);
  uint32_t x15 = ((uint32_t)(arg1[51]) << 2);
  uint32_t x16 = ((uint32_t)(arg1[50]) << 23);
  uint32_t x17 = ((uint32_t)(arg1[49]) << 15);
  uint32_t x18 = ((uint32_t)(arg1[48]) << 7);
  uint64_t x19 = ((uint64_t)(arg1[47]) << 28);
  uint32_t x20 = ((uint32_t)(arg1[46]) << 20);
  uint32_t x21 = ((uint32_t)(arg1[45]) << 12);
  uint32_t x22 = ((uint32_t)(arg1[44]) << 4);
  uint64_t x23 = ((uint64_t)(arg1[43]) << 25);
  uint32_t x24 = ((uint32_t)(arg1[42]) << 17);
  uint32_t x25 = ((uint32_t)(arg1[41]) << 9);
  uint32_t x26 = ((uint32_t)(arg1[40]) * 0x2);
  uint32_t x27 = ((uint32_t)(arg1[39]) << 22);
  uint32_t x28 = ((uint32_t)(arg1[38]) << 14);
  uint32_t x29 = ((uint32_t)(arg1[37]) << 6);
  uint64_t x30 = ((uint64_t)(arg1[36]) << 27);
  uint32_t x31 = ((uint32_t)(arg1[35]) << 19);
  uint32_t x32 = ((uint32_t)(arg1[34]) << 11);
  uint32_t x33 = ((uint32_t)(arg1[33]) << 3);
  uint32_t x34 = ((uint32_t)(arg1[32]) << 24);
  uint32_t x35 = ((uint32_t)(arg1[31]) << 16);
  uint32_t x36 = ((uint32_t)(arg1[30]) << 8);
  uint8_t x37 = (arg1[29]);
  uint32_t x38 = ((uint32_t)(arg1[28]) << 21);
  uint32_t x39 = ((uint32_t)(arg1[27]) << 13);
  uint32_t x40 = ((uint32_t)(arg1[26]) << 5);
  uint64_t x41 = ((uint64_t)(arg1[25]) << 26);
  uint32_t x42 = ((uint32_t)(arg1[24]) << 18);
  uint32_t x43 = ((uint32_t)(arg1[23]) << 10);
  uint32_t x44 = ((uint32_t)(arg1[22]) << 2);
  uint32_t x45 = ((uint32_t)(arg1[21]) << 23);
  uint32_t x46 = ((uint32_t)(arg1[20]) << 15);
  uint32_t x47 = ((uint32_t)(arg1[19]) << 7);
  uint64_t x48 = ((uint64_t)(arg1[18]) << 28);
  uint32_t x49 = ((uint32_t)(arg1[17]) << 20);
  uint32_t x50 = ((uint32_t)(arg1[16]) << 12);
  uint32_t x51 = ((uint32_t)(arg1[15]) << 4);
  uint64_t x52 = ((uint64_t)(arg1[14]) << 25);
  uint32_t x53 = ((uint32_t)(arg1[13]) << 17);
  uint32_t x54 = ((uint32_t)(arg1[12]) << 9);
  uint32_t x55 = ((uint32_t)(arg1[11]) * 0x2);
  uint32_t x56 = ((uint32_t)(arg1[10]) << 22);
  uint32_t x57 = ((uint32_t)(arg1[9]) << 14);
  uint32_t x58 = ((uint32_t)(arg1[8]) << 6);
  uint64_t x59 = ((uint64_t)(arg1[7]) << 27);
  uint32_t x60 = ((uint32_t)(arg1[6]) << 19);
  uint32_t x61 = ((uint32_t)(arg1[5]) << 11);
  uint32_t x62 = ((uint32_t)(arg1[4]) << 3);
  uint32_t x63 = ((uint32_t)(arg1[3]) << 24);
  uint32_t x64 = ((uint32_t)(arg1[2]) << 16);
  uint32_t x65 = ((uint32_t)(arg1[1]) << 8);
  uint8_t x66 = (arg1[0]);
  uint32_t x67 = (x66 + (x65 + (x64 + x63)));
  uint8_t x68 = (uint8_t)(x67 >> 29);
  uint32_t x69 = (x67 & UINT32_C(0x1fffffff));
  uint32_t x70 = (x4 + (x3 + (x2 + x1)));
  uint32_t x71 = (x8 + (x7 + (x6 + x5)));
  uint32_t x72 = (x11 + (x10 + x9));
  uint64_t x73 = (x15 + (x14 + (x13 + x12)));
  uint32_t x74 = (x18 + (x17 + x16));
  uint64_t x75 = (x22 + (x21 + (x20 + x19)));
  uint64_t x76 = (x26 + (x25 + (x24 + x23)));
  uint32_t x77 = (x29 + (x28 + x27));
  uint64_t x78 = (x33 + (x32 + (x31 + x30)));
  uint32_t x79 = (x37 + (x36 + (x35 + x34)));
  uint32_t x80 = (x40 + (x39 + x38));
  uint64_t x81 = (x44 + (x43 + (x42 + x41)));
  uint32_t x82 = (x47 + (x46 + x45));
  uint64_t x83 = (x51 + (x50 + (x49 + x48)));
  uint64_t x84 = (x55 + (x54 + (x53 + x52)));
  uint32_t x85 = (x58 + (x57 + x56));
  uint64_t x86 = (x62 + (x61 + (x60 + x59)));
  uint64_t x87 = (x68 + x86);
  uint8_t x88 = (uint8_t)(x87 >> 29);
  uint32_t x89 = (uint32_t)(x87 & UINT32_C(0x1fffffff));
  uint32_t x90 = (x88 + x85);
  fiat_p521_uint1 x91 = (fiat_p521_uint1)(x90 >> 29);
  uint32_t x92 = (x90 & UINT32_C(0x1fffffff));
  uint64_t x93 = (x91 + x84);
  uint8_t x94 = (uint8_t)(x93 >> 29);
  uint32_t x95 = (uint32_t)(x93 & UINT32_C(0x1fffffff));
  uint64_t x96 = (x94 + x83);
  uint8_t x97 = (uint8_t)(x96 >> 29);
  uint32_t x98 = (uint32_t)(x96 & UINT32_C(0x1fffffff));
  uint32_t x99 = (x97 + x82);
  uint8_t x100 = (uint8_t)(x99 >> 29);
  uint32_t x101 = (x99 & UINT32_C(0x1fffffff));
  uint64_t x102 = (x100 + x81);
  uint8_t x103 = (uint8_t)(x102 >> 29);
  uint32_t x104 = (uint32_t)(x102 & UINT32_C(0x1fffffff));
  uint32_t x105 = (x103 + x80);
  uint32_t x106 = (x105 & UINT32_C(0x1fffffff));
  uint8_t x107 = (uint8_t)(x79 >> 29);
  uint32_t x108 = (x79 & UINT32_C(0x1fffffff));
  uint64_t x109 = (x107 + x78);
  uint8_t x110 = (uint8_t)(x109 >> 29);
  uint32_t x111 = (uint32_t)(x109 & UINT32_C(0x1fffffff));
  uint32_t x112 = (x110 + x77);
  fiat_p521_uint1 x113 = (fiat_p521_uint1)(x112 >> 29);
  uint32_t x114 = (x112 & UINT32_C(0x1fffffff));
  uint64_t x115 = (x113 + x76);
  uint8_t x116 = (uint8_t)(x115 >> 29);
  uint32_t x117 = (uint32_t)(x115 & UINT32_C(0x1fffffff));
  uint64_t x118 = (x116 + x75);
  uint8_t x119 = (uint8_t)(x118 >> 29);
  uint32_t x120 = (uint32_t)(x118 & UINT32_C(0x1fffffff));
  uint32_t x121 = (x119 + x74);
  uint8_t x122 = (uint8_t)(x121 >> 29);
  uint32_t x123 = (x121 & UINT32_C(0x1fffffff));
  uint64_t x124 = (x122 + x73);
  uint8_t x125 = (uint8_t)(x124 >> 29);
  uint32_t x126 = (uint32_t)(x124 & UINT32_C(0x1fffffff));
  uint32_t x127 = (x125 + x72);
  uint32_t x128 = (x127 & UINT32_C(0x1fffffff));
  uint8_t x129 = (uint8_t)(x71 >> 29);
  uint32_t x130 = (x71 & UINT32_C(0x1fffffff));
  uint32_t x131 = (x129 + x70);
  out1[0] = x69;
  out1[1] = x89;
  out1[2] = x92;
  out1[3] = x95;
  out1[4] = x98;
  out1[5] = x101;
  out1[6] = x104;
  out1[7] = x106;
  out1[8] = x108;
  out1[9] = x111;
  out1[10] = x114;
  out1[11] = x117;
  out1[12] = x120;
  out1[13] = x123;
  out1[14] = x126;
  out1[15] = x128;
  out1[16] = x130;
  out1[17] = x131;
}

